@@ -7,7 +7,8 @@
 
 
 /*******************************************************************************
- * Copyright (c) 2025 Olivier Langella <Olivier.Langella@universite-paris-saclay.fr>.
+ * Copyright (c) 2025 Olivier Langella
+ *<Olivier.Langella@universite-paris-saclay.fr>.
  *
  * This file is part of the PAPPSOms++ library.
  *
@@ -28,6 +29,7 @@
 
 
 #include "mzcbor2mzmlcli.h"
+#include "pappsomspp/config.h"
 #include <QIODevice>
 #include <QCommandLineParser>
 #include "pappsomspp/core/processing/uimonitor/uimonitortext.h"
@@ -41,8 +43,7 @@
 #include <QDir>
 #include <sys/stat.h>
 
-
-Mzcbor2MzmlCli::Mzcbor2MzmlCli(QObject *parent) : QObject(parent)
+Mzcbor2MzmlCli::Mzcbor2MzmlCli(QObject *parent): QObject(parent)
 {
   // get the instance of the main application
   app = QCoreApplication::instance();
@@ -83,8 +84,9 @@ Mzcbor2MzmlCli::run()
 
       QCommandLineOption mzcborInputOption(
         QStringList() << "i" << "input",
-        QCoreApplication::translate(
-          "mzCBOR", "path to the mzCBOR input file <mzcbor> or use '-' to read data from stdin."),
+        QCoreApplication::translate("mzCBOR",
+                                    "path to the mzCBOR input file <mzcbor> or "
+                                    "use '-' to read data from stdin."),
         QCoreApplication::translate("mzcbor", "mzcbor"));
 
       QCommandLineOption mzmlOutputOption(
@@ -124,8 +126,9 @@ Mzcbor2MzmlCli::run()
             }
           else
             {
-              throw pappso::PappsoException(QObject::tr(
-                "input file is not set. Please provide --input or use - to read from <stdin>"));
+              throw pappso::PappsoException(
+                QObject::tr("input file is not set. Please provide --input or "
+                            "use - to read from <stdin>"));
             }
         }
       else
@@ -147,7 +150,8 @@ Mzcbor2MzmlCli::run()
             {
               qDebug();
               is_dir = true;
-              convertAllMzcborInDir(monitor, input_mzml_fileinfo, parser.value(mzmlOutputOption));
+              convertAllMzcborInDir(
+                monitor, input_mzml_fileinfo, parser.value(mzmlOutputOption));
             }
         }
 
@@ -241,7 +245,6 @@ Mzcbor2MzmlCli::aboutToQuitApp()
   // delete any objects
 }
 
-
 void
 Mzcbor2MzmlCli::convertAllMzcborInDir(pappso::UiMonitorInterface &monitor,
                                       const QFileInfo &input_dir,
@@ -268,19 +271,21 @@ Mzcbor2MzmlCli::convertAllMzcborInDir(pappso::UiMonitorInterface &monitor,
   if(!output_dir.exists())
     {
 
-      throw pappso::PappsoException(QObject::tr("ERROR the output directory does not exists :\n%1")
-                                      .arg(output_dir.absolutePath()));
+      throw pappso::PappsoException(
+        QObject::tr("ERROR the output directory does not exists :\n%1")
+          .arg(output_dir.absolutePath()));
     }
 
   for(QString &input_file_name : mzcbor_file_list)
     {
-      QString output_file_name =
-        output_dir.absoluteFilePath(QFileInfo(input_file_name).baseName().append(".mzML"));
+      QString output_file_name = output_dir.absoluteFilePath(
+        QFileInfo(input_file_name).baseName().append(".mzML"));
       qDebug() << output_file_name;
       qDebug() << input_file_name;
 
-      monitor.setStatus(
-        QObject::tr("Converting %1 to %2").arg(input_file_name).arg(output_file_name));
+      monitor.setStatus(QObject::tr("Converting %1 to %2")
+                          .arg(input_file_name)
+                          .arg(output_file_name));
       QFile input_file(input_file_name);
       if(input_file.open(QIODevice::ReadOnly))
         {
@@ -323,7 +328,8 @@ main(int argc, char **argv)
   Mzcbor2MzmlCli myMain;
   // connect up the signals
   QObject::connect(&myMain, SIGNAL(finished()), &app, SLOT(quit()));
-  QObject::connect(&app, SIGNAL(aboutToQuit()), &myMain, SLOT(aboutToQuitApp()));
+  QObject::connect(
+    &app, SIGNAL(aboutToQuit()), &myMain, SLOT(aboutToQuitApp()));
   qDebug();
 
 
