@@ -132,7 +132,8 @@ const pappso::Aa &
 pappso::AaCode::getAa(char aa_letter) const
 {
 
-  if (aa_letter == 'L') return m_leucine;
+  if(aa_letter == 'L')
+    return m_leucine;
   auto it = std::find_if(m_aaCollection.begin(), m_aaCollection.end(), [aa_letter](const Aa &aa) {
     if(aa.getLetter() == aa_letter)
       return true;
