@@ -26,20 +26,18 @@
 #include "pappsomspp/core/msrun/bafasciimsrunreader.h"
 #include "pappsomspp/core/msrun/xymsrunreader.h"
 
-#include "pappsomspp/core/utils.h"
-
-
 namespace pappso
 {
 
 
-MsFileAccessor::MsFileAccessor(const QString &file_name, const QString &xml_prefix)
+MsFileAccessor::MsFileAccessor(const QString &file_name,
+                               const QString &xml_prefix)
   : m_fileName(file_name), m_xmlPrefix(xml_prefix)
 {
   QFile file(file_name);
   if(!file.exists())
-    throw(ExceptionNotFound(
-      QObject::tr("File %1 not found.").arg(QFileInfo(file_name).absoluteFilePath())));
+    throw(ExceptionNotFound(QObject::tr("File %1 not found.")
+                              .arg(QFileInfo(file_name).absoluteFilePath())));
 
 
   m_oboPsiModTermNativeIDFormat.setAccession("MS:1000824");
@@ -49,7 +47,6 @@ MsFileAccessor::MsFileAccessor(const QString &file_name, const QString &xml_pref
     "contain spectra that can have a nativeID format.";
 }
 
-
 MsFileAccessor::MsFileAccessor(const MsFileAccessor &other)
   : m_fileName(other.m_fileName),
     m_xmlPrefix(other.m_xmlPrefix),
@@ -63,14 +60,12 @@ MsFileAccessor::~MsFileAccessor()
 {
 }
 
-
 const QString &
 MsFileAccessor::getFileName() const
 {
   return m_fileName;
 }
 
-
 Enums::MsDataFormat
 MsFileAccessor::getFileFormat() const
 {
@@ -135,15 +130,17 @@ MsFileAccessor::getOboPsiModTermFileFormat() const
         break;
       case Enums::MsDataFormat::mzML:
         term.setAccession("MS:1000584");
-        term.m_name       = "mzML format";
-        term.m_definition = "Proteomics Standards Inititative mzML file format.";
+        term.m_name = "mzML format";
+        term.m_definition =
+          "Proteomics Standards Inititative mzML file format.";
         break;
       case Enums::MsDataFormat::mzcbor:
         // mzCBOR is a direct translation of mzML
         // waiting for a true OBO term, we choose the mzML definition
         term.setAccession("MS:1000584");
-        term.m_name       = "mzML format";
-        term.m_definition = "Proteomics Standards Inititative mzML file format.";
+        term.m_name = "mzML format";
+        term.m_definition =
+          "Proteomics Standards Inititative mzML file format.";
         break;
       case Enums::MsDataFormat::mzXML:
         term.setAccession("MS:1000566");
@@ -188,7 +185,6 @@ MsFileAccessor::getOboPsiModTermFileFormat() const
   return term;
 }
 
-
 const OboPsiModTerm &
 MsFileAccessor::getOboPsiModTermNativeIDFormat() const
 {
@@ -197,7 +193,6 @@ MsFileAccessor::getOboPsiModTermNativeIDFormat() const
   return m_oboPsiModTermNativeIDFormat;
 }
 
-
 std::vector<MsRunIdCstSPtr>
 MsFileAccessor::getMsRunIds()
 {
@@ -209,7 +204,8 @@ MsFileAccessor::getMsRunIds()
 
   // try the mzcbor file reader
   MzcborMsFileReader mzcbor_ms_file_reader(m_fileName);
-  if(mzcbor_ms_file_reader.getFileFormat() == pappso::Enums::MsDataFormat::mzcbor)
+  if(mzcbor_ms_file_reader.getFileFormat() ==
+     pappso::Enums::MsDataFormat::mzcbor)
     {
       qDebug() << "sure, this is mzcbor";
 
@@ -241,7 +237,7 @@ MsFileAccessor::getMsRunIds()
       return ms_run_ids;
     }
 
-  qDebug() << "The Pwiz reader did not work.";
+  // qDebug() << "The Pwiz reader did not work.";
 
   // Try the TimsData reader
 
@@ -259,7 +255,7 @@ MsFileAccessor::getMsRunIds()
 
       if(ms_run_ids.size())
         {
-          qDebug() << "Might well be handled using the Bruker code";
+          // qDebug() << "Might well be handled using the Bruker code";
 
           m_fileName       = tims_dir;
           m_fileFormat     = tims_file_reader.getFileFormat();
@@ -271,16 +267,16 @@ MsFileAccessor::getMsRunIds()
               m_fileReaderType = pref->second;
             }
 
-          qDebug() << "Returning Bruker::tims ms run(s)."
-                   << "with preferred reader type:"
-                   << Utils::fileReaderTypeAsString(m_fileReaderType);
+          // qDebug() << "Returning Bruker::tims ms run(s)."
+          //          << "with preferred reader type:"
+          //          << Utils::fileReaderTypeAsString(m_fileReaderType);
 
           return ms_run_ids;
         }
     }
   catch(const pappso::ExceptionNotRecognized &error)
     {
-      qDebug() << "The Tims reader did not work.";
+      // qDebug() << "The Tims reader did not work.";
     }
 
 
@@ -295,7 +291,7 @@ MsFileAccessor::getMsRunIds()
 
       if(ms_run_ids.size())
         {
-          qDebug() << "Might well be handled using the BafAscii code";
+          // qDebug() << "Might well be handled using the BafAscii code";
 
           m_fileReaderType = Enums::FileReaderType::bafascii;
 
@@ -313,11 +309,11 @@ MsFileAccessor::getMsRunIds()
     }
   catch(const pappso::PappsoException &error)
     {
-      qDebug() << "This is not a BafAscii code file" << error.qwhat();
+      // qDebug() << "This is not a BafAscii code file" << error.qwhat();
     }
 
 
-  qDebug() << "The BafAscii reader did not work.";
+  // qDebug() << "The BafAscii reader did not work.";
 
   // At this point try the XyMsFileReader
 
@@ -327,7 +323,7 @@ MsFileAccessor::getMsRunIds()
 
   if(ms_run_ids.size())
     {
-      qDebug() << "Might well be handled using the XY code";
+      // qDebug() << "Might well be handled using the XY code";
 
       m_fileReaderType = Enums::FileReaderType::xy;
 
@@ -336,13 +332,12 @@ MsFileAccessor::getMsRunIds()
       return ms_run_ids;
     }
 
-  qDebug() << "The XY reader did not work.";
+  // qDebug() << "The XY reader did not work.";
 
 
   return ms_run_ids;
 }
 
-
 void
 MsFileAccessor::setPreferredFileReaderType(Enums::MsDataFormat format,
                                            Enums::FileReaderType reader_type)
@@ -359,7 +354,6 @@ MsFileAccessor::setPreferredFileReaderType(Enums::MsDataFormat format,
     }
 }
 
-
 Enums::FileReaderType
 MsFileAccessor::getpreferredFileReaderType(Enums::MsDataFormat format)
 {
@@ -375,21 +369,18 @@ MsFileAccessor::getpreferredFileReaderType(Enums::MsDataFormat format)
   return m_fileReaderType;
 }
 
-
 Enums::FileReaderType
 MsFileAccessor::getFileReaderType() const
 {
   return m_fileReaderType;
 }
 
-
 void
 MsFileAccessor::setSelectedMsRunId(MsRunIdCstSPtr ms_run_id_csp)
 {
   mcsp_selectedMsRunId = ms_run_id_csp;
 }
 
-
 MsRunIdCstSPtr
 MsFileAccessor::getSelectedMsRunId() const
 {
@@ -407,7 +398,8 @@ MsFileAccessor::buildTimsMsRunReaderMs2SPtr()
     }
   TimsMsFileReader tims_file_reader(tims_dir);
 
-  std::vector<MsRunIdCstSPtr> ms_run_ids = tims_file_reader.getMsRunIds(m_xmlPrefix);
+  std::vector<MsRunIdCstSPtr> ms_run_ids =
+    tims_file_reader.getMsRunIds(m_xmlPrefix);
 
   if(ms_run_ids.size())
     {
@@ -421,11 +413,11 @@ MsFileAccessor::buildTimsMsRunReaderMs2SPtr()
   else
     {
       throw(ExceptionNotPossible(
-        QObject::tr("Unable to read mz data directory %1 with TimsTOF reader.").arg(tims_dir)));
+        QObject::tr("Unable to read mz data directory %1 with TimsTOF reader.")
+          .arg(tims_dir)));
     }
 }
 
-
 MsRunReaderSPtr
 MsFileAccessor::msRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
 {
@@ -435,11 +427,11 @@ MsFileAccessor::msRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
   // the user might have set.
 
   if(m_fileName != ms_run_id->getFileName())
-    throw(
-      ExceptionNotPossible(QObject::tr("The MsRunId instance must have the name file name as the "
-                                       "MsFileAccessor. %1 != %2")
-                             .arg(m_fileName)
-                             .arg(ms_run_id->getFileName())));
+    throw(ExceptionNotPossible(
+      QObject::tr("The MsRunId instance must have the name file name as the "
+                  "MsFileAccessor. %1 != %2")
+        .arg(m_fileName)
+        .arg(ms_run_id->getFileName())));
 
   if(m_fileFormat == Enums::MsDataFormat::mzcbor)
     {
@@ -447,11 +439,13 @@ MsFileAccessor::msRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
 
       return std::make_shared<MzcborMsRunReader>(ms_run_id);
     }
-  else if(getpreferredFileReaderType(m_fileFormat) == Enums::FileReaderType::pwiz)
+  else if(getpreferredFileReaderType(m_fileFormat) ==
+          Enums::FileReaderType::pwiz)
     {
       qDebug() << "Returning a PwizMsRunReader.";
-      auto pwiz_reader              = std::make_shared<PwizMsRunReader>(ms_run_id);
-      m_oboPsiModTermNativeIDFormat = pwiz_reader->getOboPsiModTermNativeIDFormat();
+      auto pwiz_reader = std::make_shared<PwizMsRunReader>(ms_run_id);
+      m_oboPsiModTermNativeIDFormat =
+        pwiz_reader->getOboPsiModTermNativeIDFormat();
       return pwiz_reader;
     }
   else if(getpreferredFileReaderType(m_fileFormat) == Enums::FileReaderType::xy)
@@ -460,31 +454,38 @@ MsFileAccessor::msRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
 
       return std::make_shared<XyMsRunReader>(ms_run_id);
     }
-  else if(getpreferredFileReaderType(m_fileFormat) == Enums::FileReaderType::tims)
+  else if(getpreferredFileReaderType(m_fileFormat) ==
+          Enums::FileReaderType::tims)
     {
       qDebug() << "Returning a TimsMsRunReader Enums::FileReaderType::tims";
       return std::make_shared<TimsMsRunReader>(ms_run_id);
     }
-  else if(getpreferredFileReaderType(m_fileFormat) == Enums::FileReaderType::tims_frames)
+  else if(getpreferredFileReaderType(m_fileFormat) ==
+          Enums::FileReaderType::tims_frames)
     {
-      qDebug() << "Returning a TimsFramesMsRunReader Enums::FileReaderType::tims_frames.";
+      qDebug() << "Returning a TimsFramesMsRunReader "
+                  "Enums::FileReaderType::tims_frames.";
 
       return std::make_shared<TimsFramesMsRunReader>(ms_run_id);
     }
-  else if(getpreferredFileReaderType(m_fileFormat) == Enums::FileReaderType::tims_ms2)
+  else if(getpreferredFileReaderType(m_fileFormat) ==
+          Enums::FileReaderType::tims_ms2)
     {
-      qDebug() << "Returning a TimsMsRunReaderMs2 Enums::FileReaderType::tims_ms2";
+      qDebug()
+        << "Returning a TimsMsRunReaderMs2 Enums::FileReaderType::tims_ms2";
 
       return std::make_shared<TimsMsRunReaderMs2>(ms_run_id);
     }
-  else if(getpreferredFileReaderType(m_fileFormat) == Enums::FileReaderType::tims_dia)
+  else if(getpreferredFileReaderType(m_fileFormat) ==
+          Enums::FileReaderType::tims_dia)
     {
       qDebug() << "Returning a Enums::FileReaderType::tims_dia";
 
       // qInfo() << "std::make_shared<TimsMsRunReaderDia>(ms_run_id);";
       return std::make_shared<TimsMsRunReaderDia>(ms_run_id);
     }
-  else if(getpreferredFileReaderType(m_fileFormat) == Enums::FileReaderType::bafascii)
+  else if(getpreferredFileReaderType(m_fileFormat) ==
+          Enums::FileReaderType::bafascii)
     {
       // qDebug() << "Returning a BafAsciiMsRunReader.";
 
@@ -498,8 +499,9 @@ MsFileAccessor::msRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
         }
       else
         {
-          auto pwiz_reader              = std::make_shared<PwizMsRunReader>(ms_run_id);
-          m_oboPsiModTermNativeIDFormat = pwiz_reader->getOboPsiModTermNativeIDFormat();
+          auto pwiz_reader = std::make_shared<PwizMsRunReader>(ms_run_id);
+          m_oboPsiModTermNativeIDFormat =
+            pwiz_reader->getOboPsiModTermNativeIDFormat();
           return pwiz_reader;
         }
     }
@@ -511,7 +513,6 @@ MsFileAccessor::msRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
   return nullptr;
 }
 
-
 MsRunReaderSPtr
 MsFileAccessor::msRunReaderSPtr(std::size_t ms_run_id_index)
 {
@@ -522,7 +523,6 @@ MsFileAccessor::msRunReaderSPtr(std::size_t ms_run_id_index)
   return msRunReaderSPtr(ms_run_ids.at(ms_run_id_index));
 }
 
-
 MsRunReaderSPtr
 MsFileAccessor::msRunReaderSPtrForSelectedMsRunId()
 {
@@ -531,7 +531,6 @@ MsFileAccessor::msRunReaderSPtrForSelectedMsRunId()
   return msRunReaderSPtr(mcsp_selectedMsRunId);
 }
 
-
 MsRunReaderSPtr
 MsFileAccessor::buildMsRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
 {
@@ -539,13 +538,14 @@ MsFileAccessor::buildMsRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
 }
 
 MsRunReaderSPtr
-MsFileAccessor::buildMsRunReaderSPtr(MsRunIdCstSPtr ms_run_id,
-                                     Enums::FileReaderType preferred_file_reader_type)
+MsFileAccessor::buildMsRunReaderSPtr(
+  MsRunIdCstSPtr ms_run_id, Enums::FileReaderType preferred_file_reader_type)
 {
   QFile file(ms_run_id.get()->getFileName());
   if(!file.exists())
-    throw(ExceptionNotFound(QObject::tr("unable to build a reader : file %1 not found.")
-                              .arg(QFileInfo(ms_run_id.get()->getFileName()).absoluteFilePath())));
+    throw(ExceptionNotFound(
+      QObject::tr("unable to build a reader : file %1 not found.")
+        .arg(QFileInfo(ms_run_id.get()->getFileName()).absoluteFilePath())));
 
   Enums::MsDataFormat file_format = ms_run_id.get()->getMsDataFormat();
 
@@ -563,8 +563,9 @@ MsFileAccessor::buildMsRunReaderSPtr(MsRunIdCstSPtr ms_run_id,
     }
   else if(file_format == Enums::MsDataFormat::unknown)
     {
-      throw(PappsoException(QObject::tr("unable to build a reader for %1 : unknown file format")
-                              .arg(QFileInfo(ms_run_id.get()->getFileName()).absoluteFilePath())));
+      throw(PappsoException(
+        QObject::tr("unable to build a reader for %1 : unknown file format")
+          .arg(QFileInfo(ms_run_id.get()->getFileName()).absoluteFilePath())));
     }
 
   else if(file_format == Enums::MsDataFormat::brukerTims)
@@ -579,7 +580,8 @@ MsFileAccessor::buildMsRunReaderSPtr(MsRunIdCstSPtr ms_run_id,
         }
       else if(preferred_file_reader_type == Enums::FileReaderType::tims_frames)
         {
-          qDebug() << "returning std::make_shared<TimsFramesMsRunReader>(ms_run_id).";
+          qDebug()
+            << "returning std::make_shared<TimsFramesMsRunReader>(ms_run_id).";
           return std::make_shared<TimsFramesMsRunReader>(ms_run_id);
         }
       // qDebug() << "by default, build a TimsMsRunReader.";
@@ -596,9 +598,9 @@ MsFileAccessor::buildMsRunReaderSPtr(MsRunIdCstSPtr ms_run_id,
     }
 }
 
-
 MsRunReaderSPtr
-MsFileAccessor::getMsRunReaderSPtrByRunId(const QString &run_id, const QString &xml_id)
+MsFileAccessor::getMsRunReaderSPtrByRunId(const QString &run_id,
+                                          const QString &xml_id)
 {
   std::vector<MsRunIdCstSPtr> run_list = getMsRunIds();
   MsRunReaderSPtr reader_sp;
@@ -624,9 +626,10 @@ MsFileAccessor::getMsRunReaderSPtrByRunId(const QString &run_id, const QString &
 
   if(reader_sp == nullptr)
     {
-      throw(ExceptionNotFound(QObject::tr("run id %1 not found in file %2")
-                                .arg(run_id)
-                                .arg(QFileInfo(m_fileName).absoluteFilePath())));
+      throw(
+        ExceptionNotFound(QObject::tr("run id %1 not found in file %2")
+                            .arg(run_id)
+                            .arg(QFileInfo(m_fileName).absoluteFilePath())));
     }
   return reader_sp;
 }
