@@ -20,8 +20,8 @@ MsFileReader::MsFileReader(const QString &file_name) : m_fileName{file_name}
 {
   QFile file(file_name);
   if(!file.exists())
-    throw(ExceptionNotFound(QObject::tr("File %1 not found.")
-                              .arg(QFileInfo(file_name).absoluteFilePath())));
+    throw(ExceptionNotFound(
+      QObject::tr("File %1 not found.").arg(QFileInfo(file_name).absoluteFilePath())));
 }
 
 
