@@ -28,7 +28,6 @@
 #include "pappsomspp/core/msfile/timsmsfilereader.h"
 #include "pappsomspp/core/vendors/tims/timsdata.h"
 #include "pappsomspp/core/pappsoexception.h"
-#include "pappsomspp/core/exception/exceptionnotimplemented.h"
 #include "pappsomspp/core/exception/exceptionnotrecognized.h"
 #include <QDebug>
 #include <QFileInfo>
@@ -39,7 +38,6 @@ namespace pappso
 
 TimsMsFileReader::TimsMsFileReader(const QString &file_name) : MsFileReader(file_name)
 {
-  qDebug() << " " << m_fileName;
   initialize();
 }
 
