@@ -1,6 +1,4 @@
 /////////////////////// StdLib includes
-#include <iostream>
-#include <iomanip>
 
 
 /////////////////////// Qt includes
@@ -15,26 +13,23 @@
 
 /////////////////////// Local includes
 #include "xymsfilereader.h"
-#include "pappsomspp/core/exception/exceptionnotfound.h"
 #include "pappsomspp/core/utils.h"
 #include "pappsomspp/core/types.h"
 #include "pappsomspp/core/msrun/msrunid.h"
 
-
 namespace pappso
 {
 
 
-XyMsFileReader::XyMsFileReader(const QString &file_name) : MsFileReader{file_name}
+XyMsFileReader::XyMsFileReader(const QString &file_name)
+  : MsFileReader{file_name}
 {
 }
 
-
 XyMsFileReader::~XyMsFileReader()
 {
 }
 
-
 bool
 XyMsFileReader::initialize(std::size_t &line_count)
 {
@@ -66,10 +61,11 @@ XyMsFileReader::initialize(std::size_t &line_count)
       // if(linesRead >= 2000)
       // return true;
 
-      if(line.startsWith('#') || line.isEmpty() || Utils::endOfLineRegExp.match(line).hasMatch())
+      if(line.startsWith('#') || line.isEmpty() ||
+         Utils::endOfLineRegExp.match(line).hasMatch())
         continue;
 
-      qDebug() << "Current xy format line:" << line;
+      // qDebug() << "Current xy format line:" << line;
 
       if(Utils::xyMassDataFormatRegExp.match(line).hasMatch())
         {
@@ -100,14 +96,12 @@ XyMsFileReader::initialize(std::size_t &line_count)
   return false;
 }
 
-
 Enums::MsDataFormat
 XyMsFileReader::getFileFormat()
 {
   return m_fileFormat;
 }
 
-
 std::vector<MsRunIdCstSPtr>
 XyMsFileReader::getMsRunIds(const QString &run_prefix)
 {
@@ -123,7 +117,8 @@ XyMsFileReader::getMsRunIds(const QString &run_prefix)
   ms_run_id.setMsDataFormat(m_fileFormat);
 
   // We need to set the unambiguous xmlId string.
-  ms_run_id.setXmlId(QString("%1%2").arg(run_prefix).arg(Utils::getLexicalOrderedString(0)));
+  ms_run_id.setXmlId(
+    QString("%1%2").arg(run_prefix).arg(Utils::getLexicalOrderedString(0)));
 
   // Craft a meaningful sample name because otherwise all the files loaded from
   // text files will have the same sample name and it will be difficult to
