@@ -3,12 +3,9 @@
 
 #include <map>
 #include <limits>
-#include <iostream>
-#include <iomanip>
 
 #include "msrundatasettree.h"
 
-#include "pappsomspp/core/pappsoexception.h"
 #include "pappsomspp/core/exception/exceptionnotpossible.h"
 
 #include <QVariant>
@@ -18,11 +15,11 @@ namespace pappso
 {
 
 
-MsRunDataSetTree::MsRunDataSetTree(MsRunIdCstSPtr ms_run_id_csp) : mcsp_msRunId(ms_run_id_csp)
+MsRunDataSetTree::MsRunDataSetTree(MsRunIdCstSPtr ms_run_id_csp)
+  : mcsp_msRunId(ms_run_id_csp)
 {
 }
 
-
 MsRunDataSetTree::~MsRunDataSetTree()
 {
   // qDebug();
@@ -49,9 +46,9 @@ MsRunDataSetTree::~MsRunDataSetTree()
   // qDebug();
 }
 
-
 MsRunDataSetTreeNode *
-MsRunDataSetTree::addMassSpectrum(QualifiedMassSpectrumCstSPtr mass_spectrum_csp)
+MsRunDataSetTree::addMassSpectrum(
+  QualifiedMassSpectrumCstSPtr mass_spectrum_csp)
 {
   // qDebug();
 
@@ -66,7 +63,8 @@ MsRunDataSetTree::addMassSpectrum(QualifiedMassSpectrumCstSPtr mass_spectrum_csp
 
   MsRunDataSetTreeNode *new_node_p = nullptr;
 
-  std::size_t precursor_spectrum_index = mass_spectrum_csp->getPrecursorSpectrumIndex();
+  std::size_t precursor_spectrum_index =
+    mass_spectrum_csp->getPrecursorSpectrumIndex();
 
   // qDebug() << "The precursor_spectrum_index:" << precursor_spectrum_index;
 
@@ -105,11 +103,12 @@ MsRunDataSetTree::addMassSpectrum(QualifiedMassSpectrumCstSPtr mass_spectrum_csp
 
       if(parent_node_p == nullptr)
         {
-          throw ExceptionNotPossible(QString("%1 @ %2 - %3\n")
-                                       .arg(__FILE__)
-                                       .arg(__LINE__)
-                                       .arg("msrundatasettree.cpp -- ERROR could not find "
-                                            "a tree node matching the index."));
+          throw ExceptionNotPossible(
+            QString("%1 @ %2 - %3\n")
+              .arg(__FILE__)
+              .arg(__LINE__)
+              .arg("msrundatasettree.cpp -- ERROR could not find "
+                   "a tree node matching the index."));
         }
 
       // qDebug() << "Fragmentation spectrum"
@@ -130,7 +129,8 @@ MsRunDataSetTree::addMassSpectrum(QualifiedMassSpectrumCstSPtr mass_spectrum_csp
   // We also want to document the new node relating to the
   // retention time.
 
-  documentNodeInDtRtMap(mass_spectrum_csp->getRtInMinutes(), new_node_p, Enums::DataKind::rt);
+  documentNodeInDtRtMap(
+    mass_spectrum_csp->getRtInMinutes(), new_node_p, Enums::DataKind::rt);
 
   // Likewise for the ion mobility time.
 
@@ -144,7 +144,8 @@ MsRunDataSetTree::addMassSpectrum(QualifiedMassSpectrumCstSPtr mass_spectrum_csp
       // Start by looking if there is a OneOverK0 valid value, which
       // means we have effectively handled a genuine mobility scan spectrum.
       QVariant ion_mobility_variant_value =
-        mass_spectrum_csp->getParameterValue(QualifiedMassSpectrumParameter::IonMobOneOverK0);
+        mass_spectrum_csp->getParameterValue(
+          QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
       if(ion_mobility_variant_value.isValid())
         {
@@ -202,14 +203,12 @@ MsRunDataSetTree::addMassSpectrum(QualifiedMassSpectrumCstSPtr mass_spectrum_csp
   return new_node_p;
 }
 
-
 const std::map<std::size_t, MsRunDataSetTreeNode *> &
 MsRunDataSetTree::getIndexNodeMap() const
 {
   return m_indexNodeMap;
 }
 
-
 std::size_t
 MsRunDataSetTree::massSpectrumIndex(const MsRunDataSetTreeNode *node) const
 {
@@ -219,11 +218,12 @@ MsRunDataSetTree::massSpectrumIndex(const MsRunDataSetTreeNode *node) const
     throw("Cannot be that the node pointer is nullptr");
 
   std::map<std::size_t, MsRunDataSetTreeNode *>::const_iterator iterator =
-    std::find_if(m_indexNodeMap.begin(),
-                 m_indexNodeMap.end(),
-                 [node](const std::pair<std::size_t, MsRunDataSetTreeNode *> pair) {
-                   return pair.second == node;
-                 });
+    std::find_if(
+      m_indexNodeMap.begin(),
+      m_indexNodeMap.end(),
+      [node](const std::pair<std::size_t, MsRunDataSetTreeNode *> pair) {
+        return pair.second == node;
+      });
 
   if(iterator != m_indexNodeMap.end())
     return iterator->first;
@@ -231,23 +231,21 @@ MsRunDataSetTree::massSpectrumIndex(const MsRunDataSetTreeNode *node) const
   return std::numeric_limits<std::size_t>::max();
 }
 
-
 std::size_t
-MsRunDataSetTree::massSpectrumIndex(QualifiedMassSpectrumCstSPtr qualified_mass_spectrum_csp) const
+MsRunDataSetTree::massSpectrumIndex(
+  QualifiedMassSpectrumCstSPtr qualified_mass_spectrum_csp) const
 {
   MsRunDataSetTreeNode *node_p = findNode(qualified_mass_spectrum_csp);
 
   return massSpectrumIndex(node_p);
 }
 
-
 const std::vector<MsRunDataSetTreeNode *> &
 MsRunDataSetTree::getRootNodes() const
 {
   return m_rootNodes;
 }
 
-
 void
 MsRunDataSetTree::accept(MsRunDataSetTreeNodeVisitorInterface &visitor)
 {
@@ -264,11 +262,11 @@ MsRunDataSetTree::accept(MsRunDataSetTreeNodeVisitorInterface &visitor)
     }
 }
 
-
 void
-MsRunDataSetTree::accept(MsRunDataSetTreeNodeVisitorInterface &visitor,
-                         std::vector<MsRunDataSetTreeNode *>::const_iterator nodes_begin_iterator,
-                         std::vector<MsRunDataSetTreeNode *>::const_iterator nodes_end_iterator)
+MsRunDataSetTree::accept(
+  MsRunDataSetTreeNodeVisitorInterface &visitor,
+  std::vector<MsRunDataSetTreeNode *>::const_iterator nodes_begin_iterator,
+  std::vector<MsRunDataSetTreeNode *>::const_iterator nodes_end_iterator)
 {
   // qDebug() << "Visitor:" << &visitor << "The distance is between iterators
   // is:"
@@ -280,7 +278,8 @@ MsRunDataSetTree::accept(MsRunDataSetTreeNodeVisitorInterface &visitor,
 
   // Inform the visitor of the number of nodes to work on.
 
-  std::size_t node_count = std::distance(nodes_begin_iterator, nodes_end_iterator);
+  std::size_t node_count =
+    std::distance(nodes_begin_iterator, nodes_end_iterator);
 
   visitor.setNodesToProcessCount(node_count);
 
@@ -300,7 +299,6 @@ MsRunDataSetTree::accept(MsRunDataSetTreeNodeVisitorInterface &visitor,
     }
 }
 
-
 MsRunDataSetTreeNode *
 MsRunDataSetTree::findNode(QualifiedMassSpectrumCstSPtr mass_spectrum_csp) const
 {
@@ -318,7 +316,6 @@ MsRunDataSetTree::findNode(QualifiedMassSpectrumCstSPtr mass_spectrum_csp) const
   return nullptr;
 }
 
-
 MsRunDataSetTreeNode *
 MsRunDataSetTree::findNode(std::size_t spectrum_index) const
 {
@@ -336,7 +333,6 @@ MsRunDataSetTree::findNode(std::size_t spectrum_index) const
   return nullptr;
 }
 
-
 std::vector<MsRunDataSetTreeNode *>
 MsRunDataSetTree::flattenedView()
 {
@@ -353,9 +349,9 @@ MsRunDataSetTree::flattenedView()
   return nodes;
 }
 
-
 std::vector<MsRunDataSetTreeNode *>
-MsRunDataSetTree::flattenedViewMsLevel(std::size_t ms_level, bool with_descendants)
+MsRunDataSetTree::flattenedViewMsLevel(std::size_t ms_level,
+                                       bool with_descendants)
 {
   std::vector<MsRunDataSetTreeNode *> nodes;
 
@@ -363,7 +359,8 @@ MsRunDataSetTree::flattenedViewMsLevel(std::size_t ms_level, bool with_descendan
 
   if(!ms_level)
     {
-      throw ExceptionNotPossible("msrundatasettree.cpp -- ERROR the MS level cannot be 0.");
+      throw ExceptionNotPossible(
+        "msrundatasettree.cpp -- ERROR the MS level cannot be 0.");
 
       return nodes;
     }
@@ -414,9 +411,9 @@ MsRunDataSetTree::flattenedViewMsLevel(std::size_t ms_level, bool with_descendan
   return nodes;
 }
 
-
 MsRunDataSetTreeNode *
-MsRunDataSetTree::precursorNodeByProductSpectrumIndex(std::size_t product_spectrum_index)
+MsRunDataSetTree::precursorNodeByProductSpectrumIndex(
+  std::size_t product_spectrum_index)
 {
 
   // qDebug();
@@ -433,9 +430,9 @@ MsRunDataSetTree::precursorNodeByProductSpectrumIndex(std::size_t product_spectr
   return findNode(node->mcsp_massSpectrum->getPrecursorSpectrumIndex());
 }
 
-
 std::vector<MsRunDataSetTreeNode *>
-MsRunDataSetTree::productNodesByPrecursorSpectrumIndex(std::size_t precursor_spectrum_index)
+MsRunDataSetTree::productNodesByPrecursorSpectrumIndex(
+  std::size_t precursor_spectrum_index)
 {
   std::vector<MsRunDataSetTreeNode *> nodes;
 
@@ -446,21 +443,23 @@ MsRunDataSetTree::productNodesByPrecursorSpectrumIndex(std::size_t precursor_spe
   if(precursor_node == nullptr)
     return nodes;
 
-  nodes.assign(precursor_node->m_children.begin(), precursor_node->m_children.end());
+  nodes.assign(precursor_node->m_children.begin(),
+               precursor_node->m_children.end());
 
   return nodes;
 }
 
-
 std::vector<MsRunDataSetTreeNode *>
-MsRunDataSetTree::precursorNodesByPrecursorMz(pappso_double mz, PrecisionPtr precision_ptr)
+MsRunDataSetTree::precursorNodesByPrecursorMz(pappso_double mz,
+                                              PrecisionPtr precision_ptr)
 {
 
   // Find all the precursor nodes holding a mass spectrum that contained a
   // precursor mz-value.
 
   if(precision_ptr == nullptr)
-    throw ExceptionNotPossible("msrundatasettree.cpp -- ERROR precision_ptr cannot be nullptr.");
+    throw ExceptionNotPossible(
+      "msrundatasettree.cpp -- ERROR precision_ptr cannot be nullptr.");
 
   std::vector<MsRunDataSetTreeNode *> product_nodes;
 
@@ -479,13 +478,13 @@ MsRunDataSetTree::precursorNodesByPrecursorMz(pappso_double mz, PrecisionPtr pre
 
   for(auto &&node : product_nodes)
     {
-      precursor_nodes.push_back(findNode(node->mcsp_massSpectrum->getPrecursorSpectrumIndex()));
+      precursor_nodes.push_back(
+        findNode(node->mcsp_massSpectrum->getPrecursorSpectrumIndex()));
     }
 
   return precursor_nodes;
 }
 
-
 bool
 MsRunDataSetTree::documentNodeInDtRtMap(double time,
                                         MsRunDataSetTreeNode *node_p,
@@ -543,10 +542,10 @@ MsRunDataSetTree::documentNodeInDtRtMap(double time,
   return true;
 }
 
-
 MsRunDataSetTreeNode *
-MsRunDataSetTree::addMassSpectrum(QualifiedMassSpectrumCstSPtr mass_spectrum_csp,
-                                  MsRunDataSetTreeNode *parent_p)
+MsRunDataSetTree::addMassSpectrum(
+  QualifiedMassSpectrumCstSPtr mass_spectrum_csp,
+  MsRunDataSetTreeNode *parent_p)
 {
   // qDebug();
 
@@ -555,7 +554,8 @@ MsRunDataSetTree::addMassSpectrum(QualifiedMassSpectrumCstSPtr mass_spectrum_csp
   // of root nodes. If it is not nullptr, we need to append the mass spectrum to
   // that node.
 
-  MsRunDataSetTreeNode *new_node_p = new MsRunDataSetTreeNode(mass_spectrum_csp, parent_p);
+  MsRunDataSetTreeNode *new_node_p =
+    new MsRunDataSetTreeNode(mass_spectrum_csp, parent_p);
 
   if(parent_p == nullptr)
     {
@@ -580,7 +580,8 @@ MsRunDataSetTree::addMassSpectrum(QualifiedMassSpectrumCstSPtr mass_spectrum_csp
   // We also want to document the new node relating to the
   // retention time.
 
-  documentNodeInDtRtMap(mass_spectrum_csp->getRtInMinutes(), new_node_p, Enums::DataKind::rt);
+  documentNodeInDtRtMap(
+    mass_spectrum_csp->getRtInMinutes(), new_node_p, Enums::DataKind::rt);
 
   // Likewise for the ion mobility time.
 
@@ -594,7 +595,8 @@ MsRunDataSetTree::addMassSpectrum(QualifiedMassSpectrumCstSPtr mass_spectrum_csp
       // Start by looking if there is a OneOverK0 valid value, which
       // means we have effectively handled a genuine mobility scan spectrum.
       QVariant ion_mobility_variant_value =
-        mass_spectrum_csp->getParameterValue(QualifiedMassSpectrumParameter::IonMobOneOverK0);
+        mass_spectrum_csp->getParameterValue(
+          QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
       if(ion_mobility_variant_value.isValid())
         {
@@ -650,10 +652,10 @@ MsRunDataSetTree::addMassSpectrum(QualifiedMassSpectrumCstSPtr mass_spectrum_csp
   return new_node_p;
 }
 
-
 MsRunDataSetTreeNode *
-MsRunDataSetTree::addMassSpectrum(QualifiedMassSpectrumCstSPtr mass_spectrum_csp,
-                                  std::size_t precursor_spectrum_index)
+MsRunDataSetTree::addMassSpectrum(
+  QualifiedMassSpectrumCstSPtr mass_spectrum_csp,
+  std::size_t precursor_spectrum_index)
 {
   // qDebug();
 
@@ -665,7 +667,8 @@ MsRunDataSetTree::addMassSpectrum(QualifiedMassSpectrumCstSPtr mass_spectrum_csp
   //"spectrum index:"
   //<< precursor_spectrum_index;
 
-  MsRunDataSetTreeNode *mass_spec_data_node_p = findNode(precursor_spectrum_index);
+  MsRunDataSetTreeNode *mass_spec_data_node_p =
+    findNode(precursor_spectrum_index);
 
   // qDebug() << "Found node" << mass_spec_data_node_p
   //<< "for precursor index:" << precursor_spectrum_index;
@@ -683,15 +686,13 @@ MsRunDataSetTree::addMassSpectrum(QualifiedMassSpectrumCstSPtr mass_spectrum_csp
   return addMassSpectrum(mass_spectrum_csp, mass_spec_data_node_p);
 }
 
-
 std::size_t
-MsRunDataSetTree::addDataSetTreeNodesInsideDtOrRtRange(double start,
-                                                       double end,
-                                                       NodeVector &nodes,
-                                                       Enums::DataKind data_kind) const
+MsRunDataSetTree::addDataSetTreeNodesInsideDtOrRtRange(
+  double start, double end, NodeVector &nodes, Enums::DataKind data_kind) const
 {
-  qDebug() << "Adding ms run data set tree nodes" << "inside of [" << start << "-" << end << "]"
-           << dataKindMap[data_kind] << "range";
+  // qDebug() << "Adding ms run data set tree nodes" << "inside of [" << start
+  // << "-" << end << "]"
+  //          << dataKindMap[data_kind] << "range";
 
   using NodeVector          = std::vector<MsRunDataSetTreeNode *>;
   using DoubleNodeVectorMap = std::map<double, NodeVector>;
@@ -727,7 +728,8 @@ MsRunDataSetTree::addDataSetTreeNodesInsideDtOrRtRange(double start,
   // Now that we have the iterator range, iterate in it and get the mass spectra
   // from each item's pair.second node vector.
 
-  for(MapIterator iterator = start_iterator; iterator != end_iterator; ++iterator)
+  for(MapIterator iterator = start_iterator; iterator != end_iterator;
+      ++iterator)
     {
       // We are iterating in MapPair items.
 
@@ -747,15 +749,13 @@ MsRunDataSetTree::addDataSetTreeNodesInsideDtOrRtRange(double start,
   return added_nodes;
 }
 
-
 std::size_t
-MsRunDataSetTree::removeDataSetTreeNodesOutsideDtOrRtRange(double start,
-                                                           double end,
-                                                           NodeVector &nodes,
-                                                           Enums::DataKind data_kind) const
+MsRunDataSetTree::removeDataSetTreeNodesOutsideDtOrRtRange(
+  double start, double end, NodeVector &nodes, Enums::DataKind data_kind) const
 {
-  qDebug() << "Removing ms run data set tree nodes" << "outside of [" << start << "-" << end << "]"
-           << dataKindMap[data_kind] << "range";
+  // qDebug() << "Removing ms run data set tree nodes" << "outside of [" <<
+  // start << "-" << end << "]"
+  //          << dataKindMap[data_kind] << "range";
 
   using NodeVector         = std::vector<MsRunDataSetTreeNode *>;
   using NodeVectorIterator = NodeVector::iterator;
@@ -790,7 +790,8 @@ MsRunDataSetTree::removeDataSetTreeNodesOutsideDtOrRtRange(double start,
   // Now that we have the first_end_iterator, we can iterate between [begin --
   // first_end_iterator[
 
-  for(MapIterator iterator = map_p->begin(); iterator != first_end_iterator; ++iterator)
+  for(MapIterator iterator = map_p->begin(); iterator != first_end_iterator;
+      ++iterator)
     {
       // Remove from the nodes vector the nodes.
 
@@ -803,7 +804,8 @@ MsRunDataSetTree::removeDataSetTreeNodesOutsideDtOrRtRange(double start,
 
       for(auto &&node_p : node_vector)
         {
-          NodeVectorIterator iterator = std::find(nodes.begin(), nodes.end(), node_p);
+          NodeVectorIterator iterator =
+            std::find(nodes.begin(), nodes.end(), node_p);
 
           if(iterator != nodes.end())
             {
@@ -827,7 +829,8 @@ MsRunDataSetTree::removeDataSetTreeNodesOutsideDtOrRtRange(double start,
   if(second_first_iterator != map_p->begin())
     --second_first_iterator;
 
-  for(MapIterator iterator = second_first_iterator; iterator != map_p->end(); ++iterator)
+  for(MapIterator iterator = second_first_iterator; iterator != map_p->end();
+      ++iterator)
     {
       // We are iterating in MapPair items.
 
@@ -838,7 +841,8 @@ MsRunDataSetTree::removeDataSetTreeNodesOutsideDtOrRtRange(double start,
 
       for(auto &&node_p : node_vector)
         {
-          NodeVectorIterator iterator = std::find(nodes.begin(), nodes.end(), node_p);
+          NodeVectorIterator iterator =
+            std::find(nodes.begin(), nodes.end(), node_p);
 
           if(iterator != nodes.end())
             {
@@ -854,15 +858,15 @@ MsRunDataSetTree::removeDataSetTreeNodesOutsideDtOrRtRange(double start,
   return removed_vector_items;
 }
 
-
 std::size_t
-MsRunDataSetTree::addDataSetQualMassSpectraInsideDtOrRtRange(double start,
-                                                             double end,
-                                                             QualMassSpectraVector &mass_spectra,
-                                                             Enums::DataKind data_kind) const
+MsRunDataSetTree::addDataSetQualMassSpectraInsideDtOrRtRange(
+  double start,
+  double end,
+  QualMassSpectraVector &mass_spectra,
+  Enums::DataKind data_kind) const
 {
-  qDebug() << "Adding spectra" << "inside of [" << start << "-" << end << "]"
-           << dataKindMap[data_kind] << "range";
+  // qDebug() << "Adding spectra" << "inside of [" << start << "-" << end << "]"
+  //          << dataKindMap[data_kind] << "range";
 
   QElapsedTimer timer;
   timer.start();
@@ -899,13 +903,14 @@ MsRunDataSetTree::addDataSetQualMassSpectraInsideDtOrRtRange(double start,
   else
     qFatal("Programming error.");
 
-  QString msg = QString("The %1/mz map has size: %2 with start : %3 and end : %4\n")
-                  .arg(dataKindMap[data_kind])
-                  .arg(map_p->size())
-                  .arg(start)
-                  .arg(end);
+  // QString msg = QString("The %1/mz map has size: %2 with start : %3 and end :
+  // %4\n")
+  //                 .arg(dataKindMap[data_kind])
+  //                 .arg(map_p->size())
+  //                 .arg(start)
+  //                 .arg(end);
 
-  qDebug() << msg;
+  // qDebug() << msg;
 
   std::size_t added_mass_spectra = 0;
 
@@ -920,8 +925,9 @@ MsRunDataSetTree::addDataSetQualMassSpectraInsideDtOrRtRange(double start,
       return 0;
     }
 
-  qDebug() << "The start_iterator points to:" << start_iterator->first << "as a"
-           << dataKindMap[data_kind] << "time.";
+  // qDebug() << "The start_iterator points to:" << start_iterator->first << "as
+  // a"
+  //          << dataKindMap[data_kind] << "time.";
 
   // Now get the end of the map's useful range of items.
 
@@ -939,26 +945,30 @@ MsRunDataSetTree::addDataSetQualMassSpectraInsideDtOrRtRange(double start,
 
   if(end_iterator == map_p->end())
     {
-      qDebug() << "The end_iterator points to the end of the map."
-               << "The last map item is prev() at" << dataKindMap[data_kind]
-               << "key value: " << std::prev(end_iterator)->first;
+      // qDebug() << "The end_iterator points to the end of the map."
+      //          << "The last map item is prev() at" << dataKindMap[data_kind]
+      //          << "key value: " << std::prev(end_iterator)->first;
     }
   else
     {
-      qDebug() << "The end_iterator points to:" << end_iterator->first << "as a"
-               << dataKindMap[data_kind] << "time and the accounted key value is actually"
-               << std::prev(end_iterator)->first;
+      // qDebug() << "The end_iterator points to:" << end_iterator->first << "as
+      // a"
+      //          << dataKindMap[data_kind] << "time and the accounted key value
+      //          is actually"
+      //          << std::prev(end_iterator)->first;
     }
 
-  qDebug() << "The number of time values to iterate through the" << dataKindMap[data_kind]
-           << "/mz map:" << std::distance(start_iterator, end_iterator)
-           << "with values: start: " << start_iterator->first
-           << "and end: " << std::prev(end_iterator)->first;
+  // qDebug() << "The number of time values to iterate through the" <<
+  // dataKindMap[data_kind]
+  //          << "/mz map:" << std::distance(start_iterator, end_iterator)
+  //          << "with values: start: " << start_iterator->first
+  //          << "and end: " << std::prev(end_iterator)->first;
 
   // Now that we have the iterator range, iterate in it and get the mass
   // spectra from each item's pair.second node vector.
 
-  for(MapIterator iterator = start_iterator; iterator != end_iterator; ++iterator)
+  for(MapIterator iterator = start_iterator; iterator != end_iterator;
+      ++iterator)
     {
       // We are iterating in DoubleNodeVectorMap MapPair items,
       // with double = rt or dt and NodeVector being just that.
@@ -995,20 +1005,23 @@ MsRunDataSetTree::addDataSetQualMassSpectraInsideDtOrRtRange(double start,
         }
     }
 
-  qint64 elapsed = timer.elapsed(); // milliseconds
-
-  qDebug() << "Took" << elapsed << "ms to add" << added_mass_spectra << "mass spectra";
+  // qint64 elapsed = timer.elapsed(); // milliseconds
+  // qDebug() << "Took" << elapsed << "ms to add" << added_mass_spectra << "mass
+  // spectra";
 
   return added_mass_spectra;
 }
 
-
 std::size_t
 MsRunDataSetTree::removeDataSetQualMassSpectraOutsideDtOrRtRange(
-  double start, double end, QualMassSpectraVector &mass_spectra, Enums::DataKind data_kind) const
+  double start,
+  double end,
+  QualMassSpectraVector &mass_spectra,
+  Enums::DataKind data_kind) const
 {
-  qDebug() << "Removing spectra" << "outside of [" << start << "-" << end << "]"
-           << dataKindMap[data_kind] << "range";
+  // qDebug() << "Removing spectra" << "outside of [" << start << "-" << end <<
+  // "]"
+  //          << dataKindMap[data_kind] << "range";
 
   QElapsedTimer timer;
   timer.start();
@@ -1065,7 +1078,8 @@ MsRunDataSetTree::removeDataSetQualMassSpectraOutsideDtOrRtRange(
 
   QSet<QualifiedMassSpectrumCstSPtr> set_of_mass_spectra_to_remove;
 
-  for(MapIterator iterator = map_p->begin(); iterator != first_end_iterator; ++iterator)
+  for(MapIterator iterator = map_p->begin(); iterator != first_end_iterator;
+      ++iterator)
     {
       // We are iterating in MapPair items.
 
@@ -1073,7 +1087,8 @@ MsRunDataSetTree::removeDataSetQualMassSpectraOutsideDtOrRtRange(
 
       for(std::size_t index = 0; index < node_vector.size(); ++index)
         {
-          set_of_mass_spectra_to_remove.insert(node_vector.at(index)->getQualifiedMassSpectrum());
+          set_of_mass_spectra_to_remove.insert(
+            node_vector.at(index)->getQualifiedMassSpectrum());
 
           ++removed_vector_items;
         }
@@ -1096,7 +1111,8 @@ MsRunDataSetTree::removeDataSetQualMassSpectraOutsideDtOrRtRange(
   // qDebug() << "second_first_iterator for end:" <<
   // second_first_iterator->first;
 
-  for(MapIterator iterator = second_first_iterator; iterator != map_p->end(); ++iterator)
+  for(MapIterator iterator = second_first_iterator; iterator != map_p->end();
+      ++iterator)
     {
       // We are iterating in MapPair items.
 
@@ -1105,31 +1121,33 @@ MsRunDataSetTree::removeDataSetQualMassSpectraOutsideDtOrRtRange(
 
       for(std::size_t index = 0; index < node_vector.size(); ++index)
         {
-          set_of_mass_spectra_to_remove.insert(node_vector.at(index)->getQualifiedMassSpectrum());
+          set_of_mass_spectra_to_remove.insert(
+            node_vector.at(index)->getQualifiedMassSpectrum());
 
           ++removed_vector_items;
         }
     }
 
-  // Now that we have the set of all the mass spectra to be removed from mass_spectra...
+  // Now that we have the set of all the mass spectra to be removed from
+  // mass_spectra...
 
   mass_spectra.erase(
-    std::remove_if(mass_spectra.begin(),
-                   mass_spectra.end(),
-                   [&set_of_mass_spectra_to_remove](QualifiedMassSpectrumCstSPtr &ptr) {
-                     return set_of_mass_spectra_to_remove.find(ptr) !=
-                            set_of_mass_spectra_to_remove.end();
-                   }),
+    std::remove_if(
+      mass_spectra.begin(),
+      mass_spectra.end(),
+      [&set_of_mass_spectra_to_remove](QualifiedMassSpectrumCstSPtr &ptr) {
+        return set_of_mass_spectra_to_remove.find(ptr) !=
+               set_of_mass_spectra_to_remove.end();
+      }),
     mass_spectra.end());
 
-  qint64 elapsed = timer.elapsed(); // milliseconds
-
-  qDebug() << "Took" << elapsed << "ms to remove" << removed_vector_items << "mass spectra";
+  // qint64 elapsed = timer.elapsed(); // milliseconds
+  // qDebug() << "Took" << elapsed << "ms to remove" << removed_vector_items <<
+  // "mass spectra";
 
   return removed_vector_items;
 }
 
-
 std::size_t
 MsRunDataSetTree::depth() const
 {
@@ -1162,7 +1180,6 @@ MsRunDataSetTree::depth() const
   return greatest_depth;
 }
 
-
 std::size_t
 MsRunDataSetTree::size() const
 {
@@ -1179,14 +1196,12 @@ MsRunDataSetTree::size() const
   return cumulative_node_count;
 }
 
-
 std::size_t
 MsRunDataSetTree::indexNodeMapSize() const
 {
   return m_indexNodeMap.size();
 }
 
-
 std::size_t
 MsRunDataSetTree::getSpectrumCount() const
 {
