@@ -100,7 +100,7 @@ MsRunId::setFileName(const QString &file_name)
     {
       m_fileName = file_name;
     }
-  
+
   QString extension = fileinfo.suffix();
 
   if(m_sampleName.isEmpty())
@@ -123,6 +123,10 @@ MsRunId::setFileName(const QString &file_name)
     {
       m_mzFormat = Enums::MsDataFormat::mzML;
     }
+  else if((extension.toLower() == "mzcbor") || (extension.toLower() == "cbor"))
+    {
+      m_mzFormat = Enums::MsDataFormat::mzcbor;
+    }
 }
 
 void
