@@ -1,5 +1,5 @@
 /**
- * \file pappsomspp/msrun/private/timsmsrunreader.cpp
+ * \file pappsomspp/core/msrun/private/mzcbormsrunreader.cpp
  * \date 21/11/2025
  * \author Olivier Langella
  * \brief MSrun file reader for mzcbor
@@ -628,4 +628,15 @@ MzcborMsRunReader::getRetentionTimeLine()
   return time_line;
 }
 
+std::shared_ptr<pappso::cbor::mzcbor::Spectrum>
+MzcborMsRunReader::getMzcborSpectrumSp(std::size_t spectrum_index, bool want_binary_data) const
+{
+  std::shared_ptr<pappso::cbor::mzcbor::Spectrum> cbor_spectrum_sp =
+    std::make_shared<pappso::cbor::mzcbor::Spectrum>();
+
+  fillMzcborSpectrum(spectrum_index, *cbor_spectrum_sp, want_binary_data);
+
+  return cbor_spectrum_sp;
+}
+
 } // namespace pappso
