@@ -86,6 +86,28 @@ CborStreamReader::readArray(std::vector<double> &double_list)
   return true;
 }
 
+bool
+CborStreamReader::readArray(std::vector<std::uint8_t> &small_int_list)
+{
+
+  enterContainer();
+  while(!lastError() && hasNext())
+    {
+      if(isInteger())
+        {
+          small_int_list.push_back(toInteger());
+        }
+      else
+        {
+          return false;
+        }
+      next();
+      //}
+    }
+  leaveContainer();
+  return true;
+}
+
 bool
 CborStreamReader::readArray(std::vector<int> &positions)
 {
