@@ -33,9 +33,23 @@ pappso::cbor::CborStreamReaderInterface::CborStreamReaderInterface()
 
 pappso::cbor::CborStreamReaderInterface::~CborStreamReaderInterface()
 {
+  // qWarning() << "~CborStreamReaderInterface";
+  if(mpa_cborReader != nullptr)
+    delete mpa_cborReader;
+  mpa_cborReader = nullptr;
 }
 
 
+void
+pappso::cbor::CborStreamReaderInterface::close()
+{
+  // qWarning() << "close PsmFileReaderBase";
+  if(mpa_cborReader != nullptr)
+    delete mpa_cborReader;
+  mpa_cborReader = nullptr;
+  // qWarning() << "close PsmFileReaderBase";
+}
+
 bool
 pappso::cbor::CborStreamReaderInterface::getExpectedString()
 {
@@ -51,6 +65,17 @@ pappso::cbor::CborStreamReaderInterface::getExpectedString()
 }
 
 
+void
+pappso::cbor::CborStreamReaderInterface::initCborReader(QIODevice *pcborfile)
+{
+
+  if(mpa_cborReader != nullptr)
+    delete mpa_cborReader;
+  mpa_cborReader = nullptr;
+  mpa_cborReader = new CborStreamReader();
+  // just use the QIODevice
+  mpa_cborReader->setDevice(pcborfile);
+}
 void
 pappso::cbor::CborStreamReaderInterface::initCborReader(QFile *pcborfile)
 {
