@@ -181,5 +181,46 @@ CborStreamWriter::writeCborArray(const QCborArray &cbor_array)
   QCborValue(cbor_array).toCbor(*this);
 }
 
+void
+CborStreamWriter::writeTrace(const pappso::Trace &trace,
+                             const QString &x_label,
+                             const QString &y_label)
+{
+  startMap(2);
+  append(x_label);
+  writeArray(trace.xValues());
+  append(y_label);
+  writeArray(trace.yValues());
+  endMap();
+}
+
+
+void
+CborStreamWriter::writeXicCoord(const pappso::XicCoord &xic_coord)
+{
+  startMap();
+  xic_coord.writeCborStream(*this);
+
+  if(xic_coord.xicSptr.get() != nullptr)
+    {
+      append("xic");
+      writeTrace(*xic_coord.xicSptr.get(), "rt", "intensities");
+    }
+  endMap();
+}
+
+
+void
+CborStreamWriter::writeXicCoordList(const std::vector<pappso::XicCoordSPtr> &xic_coord_list)
+{
+
+  startArray(xic_coord_list.size());
+  for(auto &xic_coord_sp : xic_coord_list)
+    {
+      writeXicCoord(*xic_coord_sp.get());
+    }
+  endArray();
+}
+
 } // namespace cbor
 } // namespace pappso
