@@ -30,14 +30,16 @@
 #include <QCborMap>
 
 
+#include "pappsomspp/core/msrun/xiccoord/xiccoord.h"
 #include "pappsomspp/export-import-config.h"
+#include "pappsomspp/core/trace/trace.h"
+
 
 namespace pappso
 {
 namespace cbor
 {
-/**
- * @todo write docs
+/** @brief overrides QCborStreamWriter base class to provide convenient functions
  */
 class PMSPP_LIB_DECL CborStreamWriter : public QCborStreamWriter
 {
@@ -54,9 +56,14 @@ class PMSPP_LIB_DECL CborStreamWriter : public QCborStreamWriter
   virtual ~CborStreamWriter();
 
 
+  /** @brief get UUID intialized when using @ref writeInformations
+   * @return QString for the UUID
+   */
   const QString &getUuid() const;
 
-
+  /** @brief automatically produces an informations CBOR map
+   * the "informations" map contains default parameters : software, versions, UUID
+   */
   void writeInformations(const QString &software_name,
                          const QString &software_version,
                          const QString &type,
@@ -73,6 +80,26 @@ class PMSPP_LIB_DECL CborStreamWriter : public QCborStreamWriter
   void writeArray(const QStringList &str_list);
   void writeArray(const std::vector<QString> &str_list);
 
+  /** @brief serialize a PAPPSO trace object to CBOR
+   * @param trace PAPPSO trace object reference
+   * @param x_label label for first dimension (x by default)
+   * @param y_label label for second dimension (y by default)
+   */
+  void writeTrace(const pappso::Trace &trace,
+                  const QString &x_label = "x",
+                  const QString &y_label = "y");
+
+
+  /** @brief serialize a PAPPSO xic coordinate object to CBOR
+   * @param xic PAPPSO object reference
+   */
+  void writeXicCoord(const pappso::XicCoord &xic_coord);
+
+  /** @brief serialize a PAPPSO xic coordinate object list to CBOR
+   * @param xic_coord_list PAPPSO object reference
+   */
+  void writeXicCoordList(const std::vector<pappso::XicCoordSPtr> &xic_coord_list);
+
   private:
   QString m_uuid;
 };
