@@ -29,6 +29,7 @@
 #include "binarydataarray.h"
 #include "cvparam.h"
 #include "pappsomspp/core/pappsoexception.h"
+#include <qjsonarray.h>
 #include <zlib.h>
 
 void
@@ -130,8 +131,10 @@ void
 pappso::cbor::mzcbor::BinaryDataArray::fromMzml(QXmlStreamReader &reader)
 {
 
+  qDebug();
   //<binaryDataArray encodedLength="6380">
   std::size_t encodedLength = reader.attributes().value("encodedLength").toULongLong();
+  qDebug() << "encodedLength=" << encodedLength;
   while(reader.readNext() && !reader.isEndElement())
     {
       if(reader.isStartElement())
@@ -140,6 +143,7 @@ pappso::cbor::mzcbor::BinaryDataArray::fromMzml(QXmlStreamReader &reader)
             {
               QString accession = reader.attributes().value("accession").toString();
 
+              qDebug() << "accession=" << accession;
               //<cvParam cvRef="MS" accession="MS:1000523" value="" name="64-bit float" />
               if(accession == "MS:1000523")
                 {
@@ -210,6 +214,21 @@ is_a: MS:1000518 ! binary data type
                   //            <cvParam cvRef="MS" accession="MS:1000514" value="" name="m/z array"
                   //            unitAccession="MS:1000040" unitName="m/z" unitCvRef="MS" />
 
+                  unit = accession;
+                }
+              else if(accession == "MS:1000595")
+                {
+                  //   <cvParam cvRef="MS" accession="MS:1000595" name="time array" value=""
+                  //   unitCvRef="UO" unitAccession="UO:0000031" unitName="minute"/>
+
+                  unit = accession;
+                }
+              else if(accession == "MS:1000786")
+                {
+                  //           <cvParam cvRef="MS" accession="MS:1000786" name="non-standard data
+                  //           array" value="ms level" unitCvRef="UO" unitAccession="UO:0000186"
+                  //           unitName="dimensionless unit"/>
+                  //
                   unit = accession;
                 }
               else
@@ -217,6 +236,9 @@ is_a: MS:1000518 ! binary data type
                   reader.raiseError(
                     QObject::tr("cvParam accession %1 is not known in binaryDataArray")
                       .arg(accession));
+                  throw pappso::PappsoException(
+                    QObject::tr("cvParam accession %1 is not known in binaryDataArray")
+                      .arg(accession));
                 }
               reader.skipCurrentElement();
             }
@@ -259,6 +281,7 @@ is_a: MS:1000518 ! binary data type
             }
         }
     }
+  qDebug();
 }
 
 
@@ -297,6 +320,38 @@ pappso::cbor::mzcbor::BinaryDataArray::toMzml(QXmlStreamWriter &writer)
       cv_param.setValue("");
       cv_param.toMzml(writer);
     }
+  else if(unit == "MS:1000595")
+    {
+      //   <cvParam cvRef="MS" accession="MS:1000595" name="time array" value=""
+      //   unitCvRef="UO" unitAccession="UO:0000031" unitName="minute"/>
+
+      cv_param.accession     = unit;
+      cv_param.name          = "time array";
+      cv_param.unitCvRef     = "UO";
+      cv_param.unitAccession = "UO:0000031";
+      cv_param.unitName      = "minute";
+      cv_param.setValue("");
+      cv_param.toMzml(writer);
+    }
+  else if(unit == "MS:1000786")
+    {
+      //           <cvParam cvRef="MS" accession="MS:1000786" name="non-standard data
+      //           array" value="ms level" unitCvRef="UO" unitAccession="UO:0000186"
+      //           unitName="dimensionless unit"/>
+      //
+      cv_param.accession     = unit;
+      cv_param.name          = "non-standard data array";
+      cv_param.unitCvRef     = "UO";
+      cv_param.unitAccession = "UO:0000186";
+      cv_param.unitName      = "dimensionless unit";
+      cv_param.setValue("ms level");
+      cv_param.toMzml(writer);
+    }
+  else
+    {
+      throw pappso::PappsoException(
+        QObject::tr("unit accession %1 is not known in binaryDataArray").arg(unit));
+    }
 
   //          <cvParam cvRef="MS" accession="MS:1000523" value="" name="64-bit float" />
 
@@ -518,3 +573,22 @@ pappso::cbor::mzcbor::BinaryDataArray::isMz() const
 
   return unit == "MS:1000514";
 }
+
+QJsonObject
+pappso::cbor::mzcbor::BinaryDataArray::toJsonObject(std::size_t estimated_length) const
+{
+  QJsonObject binary_data;
+  binary_data.insert("unit", unit);
+  std::vector<double> double_list;
+  decodeVector(estimated_length, double_list);
+
+  QJsonArray double_array;
+
+  for(auto &value : double_list)
+    {
+      double_array.append(value);
+    }
+
+  binary_data.insert("array", double_array);
+  return binary_data;
+}
