@@ -28,19 +28,25 @@
 
 #include "spectrum.h"
 #include "pappsomspp/core/exception/exceptionnotfound.h"
+#include "pappsomspp/core/processing/cbor/mzcbor/cvparammap.h"
+#include "pappsomspp/core/processing/cbor/mzcbor/scan.h"
+#include <qjsonarray.h>
+#include <qjsonobject.h>
+#include <qtypes.h>
+#include <unistd.h>
 
 
 void
 pappso::cbor::mzcbor::Spectrum::fromCbor(CborStreamReader &reader, bool want_binary_data)
 {
   QString txt_value;
-  cborBinaryDataArray.clear();
+  // cborBinaryDataArray.clear();
   precursorList.clear();
   defaultArrayLength = 0;
   index              = 0;
   cvParamMap.clear();
   scanListCvParamMap.clear();
-  scanCvParamMap.clear();
+  scanList.clear();
   id.clear();
   qDebug();
 
@@ -75,7 +81,7 @@ pappso::cbor::mzcbor::Spectrum::fromCbor(CborStreamReader &reader, bool want_bin
                 }
               else if(txt_value == "cvParam")
                 {
-                  cvParamMap = CvParam::getCvParamsMapFromCbor(reader);
+                  cvParamMap.fromCbor(reader);
                 }
               else if(txt_value == "scanList")
                 {
@@ -91,16 +97,19 @@ pappso::cbor::mzcbor::Spectrum::fromCbor(CborStreamReader &reader, bool want_bin
                               qDebug() << txt_value;
                               if(txt_value == "cvParam")
                                 {
-                                  scanListCvParamMap = CvParam::getCvParamsMapFromCbor(reader);
+                                  scanListCvParamMap.fromCbor(reader);
                                 }
                               else if(txt_value == "scan")
                                 {
                                   // scan array
                                   reader.enterContainer();
-                                  while(reader.hasNext())
+
+                                  while(reader.hasNext() && (!reader.isInvalid()))
                                     {
-                                      auto new_cv = readScanCvParams(reader);
-                                      scanCvParamMap.insert(new_cv.begin(), new_cv.end());
+                                      // scan array
+                                      Scan scan;
+                                      scan.fromCbor(reader);
+                                      scanList.emplace_back(scan);
                                     }
                                   reader.leaveContainer();
                                 }
@@ -132,7 +141,7 @@ pappso::cbor::mzcbor::Spectrum::fromCbor(CborStreamReader &reader, bool want_bin
 
                               if(txt_value == "cvParam")
                                 {
-                                  precursorListCvParamMap = CvParam::getCvParamsMapFromCbor(reader);
+                                  precursorListCvParamMap.fromCbor(reader);
                                 }
                               else if(txt_value == "precursor")
                                 {
@@ -215,10 +224,57 @@ pappso::cbor::mzcbor::Spectrum::fromCbor(CborStreamReader &reader, bool want_bin
 }
 
 
+QJsonObject
+pappso::cbor::mzcbor::Spectrum::toJsonObject() const
+{
+  QJsonObject spectrum_json;
+  spectrum_json.insert("id", id);
+  spectrum_json.insert("index", (qint64)index);
+  spectrum_json.insert("defaultArrayLength", (qint64)defaultArrayLength);
+  spectrum_json.insert("cvParam", cvParamMap.toJsonArray());
+
+  QJsonObject scan_list;
+  // QJsonObject scan_list_cvparam;
+  scan_list.insert("cvParam", scanListCvParamMap.toJsonArray());
+  QJsonArray scan_array;
+  for(auto &scan : scanList)
+    {
+      scan_array.append(scan.toJsonObject());
+    }
+  scan_list.insert("scan", scan_array);
+  spectrum_json.insert("scanList", scan_list);
+
+  if(!precursorList.empty())
+    {
+      QJsonObject precursor_list;
+      // QJsonObject scan_list_cvparam;
+      precursor_list.insert("cvParam", precursorListCvParamMap.toJsonArray());
+      QJsonArray precursor_array;
+      for(auto &precursor : precursorList)
+        {
+          precursor_array.append(precursor.toJsonObject());
+        }
+      precursor_list.insert("precursor", precursor_array);
+      spectrum_json.insert("precursorList", precursor_list);
+    }
+
+  if(!binaryDataArrayList.empty())
+    {
+      Trace trace;
+
+      decodeTrace(trace);
+
+
+      spectrum_json.insert("spectrum", trace.toJsonObject());
+    }
+
+  return spectrum_json;
+}
+
 std::map<QString, pappso::cbor::mzcbor::CvParam>
 pappso::cbor::mzcbor::Spectrum::readScanCvParams(CborStreamReader &reader)
 {
-  std::map<QString, CvParam> cv_params;
+  CvParamMap cv_params;
   reader.enterContainer();
   QString txt_value;
 
@@ -231,7 +287,7 @@ pappso::cbor::mzcbor::Spectrum::readScanCvParams(CborStreamReader &reader)
               qDebug() << txt_value;
               if(txt_value == "cvParam")
                 {
-                  cv_params = CvParam::getCvParamsMapFromCbor(reader);
+                  cv_params.fromCbor(reader);
                 }
               else
                 {
@@ -282,28 +338,19 @@ pappso::cbor::mzcbor::Spectrum::getMsLevel() const
 double
 pappso::cbor::mzcbor::Spectrum::getRtInSeconds() const
 {
-  //            <cvParam cvRef="MS" accession="MS:1000016" value="0.0048758833" name="scan start
-  //            time" unitAccession="UO:0000031" unitName="minute" unitCvRef="UO" />
-
-  auto it = scanCvParamMap.find("MS:1000016");
-  if(it == scanCvParamMap.end())
+  if(scanList.size() == 0)
     {
-      throw pappso::ExceptionNotFound(QObject::tr("retention time not found in cvParam map"));
+      throw pappso::ExceptionNotFound(QObject::tr("scan list is empty in spectrum"));
     }
-  double rt_seconds = it->second.valueDouble;
-  if(it->second.unitAccession == "UO:0000031")
+  if(scanList.size() > 1)
     {
-      // // minutes
-      rt_seconds = rt_seconds * 60;
+      throw pappso::ExceptionNotFound(QObject::tr("too many scans in spectrum"));
     }
-
-  //              <cvParam cvRef="MS" accession="MS:1000016" value="0" name="scan start time"
-  //              unitAccession="UO:0000031" unitName="minute" unitCvRef="UO" />
-  return rt_seconds;
+  return scanList.front().getRtInSeconds();
 }
 
 void
-pappso::cbor::mzcbor::Spectrum::decodeTrace(pappso::Trace &trace)
+pappso::cbor::mzcbor::Spectrum::decodeTrace(pappso::Trace &trace) const
 {
   std::vector<pappso_double> xVector;
   std::vector<pappso_double> yVector;
