@@ -30,7 +30,8 @@
 #include <QString>
 #include "pappsomspp/core/trace/trace.h"
 #include "pappsomspp/core/processing/cbor/cborstreamreader.h"
-#include "pappsomspp/core/processing/cbor/mzcbor/cvparam.h"
+#include "pappsomspp/core/processing/cbor/mzcbor/cvparammap.h"
+#include "pappsomspp/core/processing/cbor/mzcbor/scan.h"
 #include "pappsomspp/core/processing/cbor/mzcbor/precursor.h"
 #include "pappsomspp/core/processing/cbor/mzcbor/binarydataarray.h"
 
@@ -45,11 +46,24 @@ namespace mzcbor
  */
 struct Spectrum
 {
+  /** @brief fill the structure reading data from a CBOR stream
+   * @param reader CBOR stream
+   * @param want_binary_data if true, stores also binary data array list
+   */
   void fromCbor(CborStreamReader &reader, bool want_binary_data);
+
+  /** @brief write the structure to a JSON object
+   * This is a simplified representation for easy JSON data handling
+   * binary arrays are decoded in simple traces
+   * @result QJsonObject
+   */
+  QJsonObject toJsonObject() const;
+
+
   static std::map<QString, pappso::cbor::mzcbor::CvParam>
   readScanCvParams(CborStreamReader &reader);
 
-  void decodeTrace(pappso::Trace &trace);
+  void decodeTrace(pappso::Trace &trace) const;
 
   uint getMsLevel() const;
   double getRtInSeconds() const;
@@ -59,14 +73,14 @@ struct Spectrum
   std::size_t index;
   std::size_t defaultArrayLength;
 
-  std::map<QString, pappso::cbor::mzcbor::CvParam> cvParamMap;
-  std::map<QString, pappso::cbor::mzcbor::CvParam> scanListCvParamMap;
-  std::map<QString, pappso::cbor::mzcbor::CvParam> scanCvParamMap;
-  std::map<QString, pappso::cbor::mzcbor::CvParam> precursorListCvParamMap;
-  QCborMap cborScanList;
+  CvParamMap cvParamMap;
+  CvParamMap scanListCvParamMap;
+  CvParamMap precursorListCvParamMap;
+  // QCborMap cborScanList;
+  std::vector<Scan> scanList;
   std::vector<Precursor> precursorList;
   std::vector<BinaryDataArray> binaryDataArrayList;
-  QCborMap cborBinaryDataArray;
+  // QCborMap cborBinaryDataArray;
 };
 } // namespace mzcbor
 } // namespace cbor
