@@ -1,17 +1,13 @@
 #pragma once
 
-#include <vector>
 #include <memory>
 
 #include <QDataStream>
 
 
 #include "pappsomspp/export-import-config.h"
-#include "../../types.h"
 #include "../../trace/trace.h"
 #include "../../trace/maptrace.h"
-#include "../../trace/datapoint.h"
-#include "../../mzrange.h"
 #include "massdatacombinerinterface.h"
 
 
