@@ -49,18 +49,23 @@ namespace pappso
 {
 
 
-FilterLowIntensitySignalRemoval::FilterLowIntensitySignalRemoval(
-  double mean, double std_dev, double threshold)
+FilterLowIntensitySignalRemoval::FilterLowIntensitySignalRemoval(double mean,
+                                                                 double std_dev,
+                                                                 double threshold)
 {
+  // qDebug() << "Building with parameters: [ mean:" << mean << "- std_dev:" << std_dev
+  //          << "- threshold" << threshold << "]";
+
   m_noiseMean   = mean;
   m_noiseStdDev = std_dev;
   m_threshold   = threshold;
 }
 
 
-FilterLowIntensitySignalRemoval::FilterLowIntensitySignalRemoval(
-  const QString &parameters)
+FilterLowIntensitySignalRemoval::FilterLowIntensitySignalRemoval(const QString &parameters)
 {
+  // qDebug() << "Building with parameters:" << parameters;
+
   buildFilterFromString(parameters);
 }
 
@@ -80,8 +85,7 @@ FilterLowIntensitySignalRemoval::~FilterLowIntensitySignalRemoval()
 
 
 FilterLowIntensitySignalRemoval &
-FilterLowIntensitySignalRemoval::operator=(
-  const FilterLowIntensitySignalRemoval &other)
+FilterLowIntensitySignalRemoval::operator=(const FilterLowIntensitySignalRemoval &other)
 {
   if(&other == this)
     return *this;
@@ -95,14 +99,21 @@ FilterLowIntensitySignalRemoval::operator=(
 
 
 void
-FilterLowIntensitySignalRemoval::buildFilterFromString(
-  const QString &parameters)
+FilterLowIntensitySignalRemoval::buildFilterFromString(const QString &parameters)
 {
-  // Typical string: "FloorAmplitudePercentage|15"
+  // qDebug();
+
+  // Typical string: "FilterLowIntensitySignalRemoval|2000"
   if(parameters.startsWith(QString("%1|").arg(name())))
     {
       QStringList params = parameters.split("|").back().split(";");
 
+      if(params.size() != 3)
+        throw pappso::ExceptionNotRecognized(
+          QString("Building of FilterLowIntensitySignalRemoval from string '%1' failed. Expected "
+                  "name and three parameters.")
+            .arg(parameters));
+
       m_noiseMean   = params.at(0).toDouble();
       m_noiseStdDev = params.at(1).toDouble();
       m_threshold   = params.at(2).toDouble();
@@ -110,8 +121,7 @@ FilterLowIntensitySignalRemoval::buildFilterFromString(
   else
     {
       throw pappso::ExceptionNotRecognized(
-        QString(
-          "Building of FilterLowIntensitySignalRemoval from string %1 failed")
+        QString("Building of FilterLowIntensitySignalRemoval from string %1 failed")
           .arg(parameters));
     }
 }
@@ -213,8 +223,7 @@ FilterLowIntensitySignalRemoval::detectClusterApices(const Trace &trace)
                 {
                   // Was that apex far on the left of the current apex ?
 
-                  if(m_curApex->x - m_prevApex->x >
-                     INTRA_CLUSTER_INTER_PEAK_DISTANCE)
+                  if(m_curApex->x - m_prevApex->x > INTRA_CLUSTER_INTER_PEAK_DISTANCE)
                     // The distance is not compatible with both apices to belong
                     // to the same apices cluster.
                     {
@@ -567,18 +576,15 @@ FilterLowIntensitySignalRemoval::reconstructTrace(const Trace &trace)
       // qDebug() << "Iterating in a new cluster apices with boundaries:"
       //<< begin_iter->x << "-" << end_iter->x;
 
-      left_begin_iter =
-        backwardFindApex(trace, begin_iter, INTRA_CLUSTER_INTER_PEAK_DISTANCE);
+      left_begin_iter = backwardFindApex(trace, begin_iter, INTRA_CLUSTER_INTER_PEAK_DISTANCE);
 
       // qDebug() << "After backwardFindApex, left_begin_iter points to:"
       //<< left_begin_iter->toString() << "with distance:"
       //<< std::distance(left_begin_iter, begin_iter);
 
-      right_end_iter = forwardFindApex(
-        trace, end_iter, 1.5 * INTRA_CLUSTER_INTER_PEAK_DISTANCE);
+      right_end_iter = forwardFindApex(trace, end_iter, 1.5 * INTRA_CLUSTER_INTER_PEAK_DISTANCE);
 
-      for(Trace::const_iterator iter = left_begin_iter; iter != right_end_iter;
-          ++iter)
+      for(Trace::const_iterator iter = left_begin_iter; iter != right_end_iter; ++iter)
         {
           map_trace[iter->x] = iter->y;
         }
@@ -600,8 +606,7 @@ FilterLowIntensitySignalRemoval::filter(Trace &trace) const
   // qDebug();
 
   // Horrible hack to have a non const filtering process.
-  return const_cast<FilterLowIntensitySignalRemoval *>(this)->nonConstFilter(
-    trace);
+  return const_cast<FilterLowIntensitySignalRemoval *>(this)->nonConstFilter(trace);
 }
 
 
@@ -648,7 +653,11 @@ FilterLowIntensitySignalRemoval::getThreshold() const
 QString
 FilterLowIntensitySignalRemoval::toString() const
 {
-  return QString("%1|%2").arg(name()).arg(QString::number(m_threshold, 'f', 2));
+  return QString("%1|%2;%3;%4")
+    .arg(name())
+    .arg(QString::number(m_noiseMean, 'f', 2))
+    .arg(QString::number(m_noiseStdDev, 'f', 2))
+    .arg(QString::number(m_threshold, 'f', 2));
 }
 
 
