@@ -38,6 +38,7 @@
 #include <algorithm>
 #include <QString>
 #include "spomsprotein.h"
+#include "pappsomspp/export-import-config.h"
 
 namespace pappso
 {
@@ -74,7 +75,7 @@ struct Location
   const SpOMSProtein *proteinPtr;
 };
 
-class LocationSaver
+class PMSPP_LIB_DECL LocationSaver
 {
   public:
   /**
