@@ -36,7 +36,6 @@
 #include "semiglobalalignment.h"
 #include "pappsomspp/core/processing/specpeptidoms/types.h"
 #include "pappsomspp/core/amino_acid/aacode.h"
-#include "pappsomspp/core/protein/protein.h"
 #include "correctiontree.h"
 #include "pappsomspp/core/pappsoexception.h"
 #include "pappsomspp/core/exception/exceptionoutofrange.h"
@@ -102,6 +101,24 @@ pappso::specpeptidoms::SemiGlobalAlignment::getInterestCells() const
 void
 pappso::specpeptidoms::SemiGlobalAlignment::fastAlign(const SpOMSSpectrum &spectrum,
                                                       const SpOMSProtein *protein_ptr)
+{
+  std::size_t sequence_length = protein_ptr->size();
+
+  initFastAlign(spectrum);
+
+  for(std::size_t row_number = 1; row_number <= sequence_length; row_number++)
+    {
+      updateAlignmentMatrix(*protein_ptr,
+                            row_number,
+                            spectrum.getAaPositions(protein_ptr->at(row_number - 1).code),
+                            spectrum,
+                            true,
+                            protein_ptr);
+    }
+}
+
+void
+pappso::specpeptidoms::SemiGlobalAlignment::initFastAlign(const SpOMSSpectrum &spectrum)
 {
   // m_scenario.clear();
   //  TODO don't forget to reset any important variable
@@ -109,8 +126,6 @@ pappso::specpeptidoms::SemiGlobalAlignment::fastAlign(const SpOMSSpectrum &spect
   // m_best_corrected_alignment.reset();
   // m_best_post_processed_alignment.reset();
 
-  std::size_t sequence_length = protein_ptr->size();
-
   KeyCell key_cell_init;
   key_cell_init.n_row     = 0;
   key_cell_init.score     = m_scorevalues.get(ScoreType::init);
@@ -124,15 +139,6 @@ pappso::specpeptidoms::SemiGlobalAlignment::fastAlign(const SpOMSSpectrum &spect
 
   // m_location_saver.resetLocationSaver();
   m_updated_cells.clear();
-  for(std::size_t row_number = 1; row_number <= sequence_length; row_number++)
-    {
-      updateAlignmentMatrix(*protein_ptr,
-                            row_number,
-                            spectrum.getAaPositions(protein_ptr->at(row_number - 1).code),
-                            spectrum,
-                            true,
-                            protein_ptr);
-    }
 }
 
 void
@@ -497,16 +503,23 @@ pappso::specpeptidoms::SemiGlobalAlignment::updateAlignmentMatrix(
 
               where = 4;
               // generic shift case (all shifts are tested)
-              shift = 0;
-              while(shift < aa_position->next_l_peak)
+              if(aa_position->l_support)
                 {
-                  tested_cell_ptr = &m_interest_cells.at(aa_position->next_l_peak - shift);
+                  shift = 1;
+                }
+              else
+                {
+                  shift = 0;
+                }
+              while(shift < aa_position->l_peak)
+                {
+                  tested_cell_ptr = &m_interest_cells.at(aa_position->l_peak - shift);
                   // verification saut parfait
                   if(perfectShiftPossible(sequence,
                                           spectrum,
                                           tested_cell_ptr->n_row,
                                           row_number,
-                                          aa_position->next_l_peak - shift,
+                                          aa_position->l_peak - shift,
                                           aa_position->r_peak) &&
                      shift <= TOL_PEAKS_MISSING)
                     {
@@ -528,7 +541,7 @@ pappso::specpeptidoms::SemiGlobalAlignment::updateAlignmentMatrix(
                     {
                       alignment_type = temp_align_type;
                       best_score     = alt_score;
-                      best_column    = aa_position->next_l_peak - shift;
+                      best_column    = aa_position->l_peak - shift;
                       beginning      = tested_cell_ptr->beginning;
                       tree_id        = tested_cell_ptr->tree_id;
                     }
@@ -1043,3 +1056,16 @@ pappso::specpeptidoms::SemiGlobalAlignment::checkSequenceDiversity(const QString
     }
   return true;
 }
+
+const std::vector<pappso::specpeptidoms::KeyCell> &
+pappso::specpeptidoms::SemiGlobalAlignment::oneAlignStep(
+  const pappso::specpeptidoms::SpOMSProtein &sequence,
+  const std::size_t row_number,
+  const std::vector<AaPosition> &aa_positions,
+  const SpOMSSpectrum &spectrum,
+  const bool fast_align,
+  const pappso::specpeptidoms::SpOMSProtein *protein_ptr)
+{
+  updateAlignmentMatrix(sequence, row_number, aa_positions, spectrum, fast_align, protein_ptr);
+  return getInterestCells();
+}
\ No newline at end of file
