@@ -157,11 +157,11 @@ pappso::specpeptidoms::SpOMSSpectrum::preprocessSpectrum()
                 }
               if(m_reindexed_peaks.at(peak1) >= 0)
                 {
-                  addAaPosition(aa, peak2, peak1, next_l_peak, true);
+                  addAaPosition(aa, peak2, peak1, true);
                 }
               else
                 {
-                  addAaPosition(aa, peak2, next_l_peak, next_l_peak, false);
+                  addAaPosition(aa, peak2, next_l_peak, false);
                 }
             }
         }
@@ -170,6 +170,17 @@ pappso::specpeptidoms::SpOMSSpectrum::preprocessSpectrum()
   removeUnsupportedMasses();
   correctPeakIndexes();
 
+  for(uint8_t aa = 1; aa < m_aaCode.getSize() + 1; ++aa)
+    {
+      qDebug() << m_aaCode.getAa(aa).getLetter();
+      for(auto iter = m_aapositions.at(aa - 1)->begin(); iter != m_aapositions.at(aa - 1)->end();
+          ++iter)
+        {
+          qDebug() << iter->l_peak << this->at(iter->l_peak).peak_mz << iter->r_peak
+                   << this->at(iter->r_peak).peak_mz << iter->l_support;
+        }
+    }
+
   // std::size_t i = 0;
   // for(auto &data_point : *this)
   //   {
@@ -237,7 +248,6 @@ void
 pappso::specpeptidoms::SpOMSSpectrum::addAaPosition(uint8_t aa,
                                                     const std::size_t r_peak,
                                                     const std::size_t l_peak,
-                                                    const std::size_t next_l_peak,
                                                     bool l_support)
 {
   // aa=0 corresponds to no amino acid identified, thus aa is always >=1. We substract 1 to aa to
@@ -245,12 +255,12 @@ pappso::specpeptidoms::SpOMSSpectrum::addAaPosition(uint8_t aa,
   if(l_support)
     {
       m_aapositions.at(aa - 1)->push_back(
-        {r_peak, l_peak, next_l_peak, computeCondition(l_peak, l_support), l_support});
+        {r_peak, l_peak, computeCondition(l_peak, l_support), l_support});
     }
   else
     {
       m_aapositions.at(aa - 1)->push_back(
-        {r_peak, next_l_peak, next_l_peak, computeCondition(l_peak, l_support), l_support});
+        {r_peak, l_peak, computeCondition(l_peak, l_support), l_support});
     }
 }
 
@@ -387,9 +397,8 @@ pappso::specpeptidoms::SpOMSSpectrum::correctPeakIndexes()
     {
       for(auto aap = aa->get()->begin(); aap != aa->get()->end(); aap++)
         {
-          aap->l_peak      = m_reindexed_peaks.at(aap->l_peak);
-          aap->r_peak      = m_reindexed_peaks.at(aap->r_peak);
-          aap->next_l_peak = m_reindexed_peaks.at(aap->next_l_peak);
+          aap->l_peak = m_reindexed_peaks.at(aap->l_peak);
+          aap->r_peak = m_reindexed_peaks.at(aap->r_peak);
         }
     }
 }
