@@ -43,8 +43,8 @@ namespace specpeptidoms
 
 struct AaPosition
 {
-  std::size_t r_peak, l_peak, next_l_peak; // If the left peak is not supported (l_support ==
-                                           // false), then l_peak = next_l_peak
+  std::size_t r_peak, l_peak; // If the left peak is not supported (l_support == false), then l_peak
+                              // is the first supported peak to the left of the actual left peak.
   /**
    * Condition is a 32 bit integer used to compute the threePeaks condition of the program.
    * The first bit is put to 1 if the AaPosition's left peak has no other amino acid directly on its
@@ -106,11 +106,8 @@ class PMSPP_LIB_DECL SpOMSSpectrum : public std::vector<specglob::ExperimentalSp
    * @param l_support indicates whether the amino acid's left support peak if supported by an amino
    * acid
    */
-  void addAaPosition(uint8_t aa,
-                     const std::size_t r_peak,
-                     const std::size_t l_peak,
-                     const std::size_t next_l_peak,
-                     bool l_support);
+  void
+  addAaPosition(uint8_t aa, const std::size_t r_peak, const std::size_t l_peak, bool l_support);
 
   /**
    * @brief Returns the list of aa_positions for a given amino acid code
