@@ -1,12 +1,11 @@
 #include <numeric>
 #include <limits>
+#include <qjsonarray.h>
 #include <qnamespace.h>
 #include <vector>
 #include <map>
 #include <cmath>
 #include <algorithm>
-#include <iostream>
-#include <iomanip>
 
 #include <QDebug>
 #include <QObject>
@@ -14,14 +13,10 @@
 #include "pappsomspp/core/utils.h"
 #include "trace.h"
 #include "maptrace.h"
-#include "pappsomspp/core/processing/combiners/tracepluscombiner.h"
-#include "pappsomspp/core/processing/combiners/traceminuscombiner.h"
 #include "pappsomspp/core/types.h"
 #include "pappsomspp/core/pappsoexception.h"
 #include "pappsomspp/core/exception/exceptionoutofrange.h"
 #include "pappsomspp/core/exception/exceptionnotpossible.h"
-#include "pappsomspp/core/processing/filters/filterresample.h"
-#include "pappsomspp/core/processing/filters/filterpass.h"
 
 
 int traceMetaTypeId    = qRegisterMetaType<pappso::Trace>("pappso::Trace");
@@ -419,6 +414,44 @@ flooredLocalMaxima(std::vector<DataPoint>::const_iterator begin,
 }
 
 
+Trace
+incrementByValueX(std::vector<DataPoint>::const_iterator begin,
+                  std::vector<DataPoint>::const_iterator end,
+                  double increment)
+{
+  Trace trace;
+  trace.reserve(std::distance(begin, end) + 1);
+
+  std::vector<DataPoint>::const_iterator the_iterator = begin;
+
+  while(the_iterator != end)
+    {
+      trace.append({the_iterator->x + increment, the_iterator->y});
+      ++the_iterator;
+    }
+
+  return trace;
+}
+
+Trace
+incrementByValueY(std::vector<DataPoint>::const_iterator begin,
+                  std::vector<DataPoint>::const_iterator end,
+                  double increment)
+{
+  Trace trace;
+  trace.reserve(std::distance(begin, end) + 1);
+
+  std::vector<DataPoint>::const_iterator the_iterator = begin;
+
+  while(the_iterator != end)
+    {
+      trace.append({the_iterator->x, the_iterator->y + increment});
+      ++the_iterator;
+    }
+
+  return trace;
+}
+
 Trace::Trace()
 {
 }
@@ -613,6 +646,7 @@ Trace::initialize(const std::map<pappso_double, pappso_double> &map)
 size_t
 Trace::initialize(const Trace &other)
 {
+  clear();
   *this = other;
 
   return size();
@@ -779,95 +813,93 @@ Trace::containsX(pappso_double value, PrecisionPtr precision_p) const
   //<< " left_most: " << left_most << " right_most: " << right_most
   //<< std::endl;
 
-  auto iterator =
-    std::find_if(begin(),
-                 end(),
-                 [value, precision_p, delta, left_most, right_most](const DataPoint &data_point) {
-                   if(precision_p)
-                     {
+  auto iterator = std::find_if(
+    begin(), end(), [value, precision_p, left_most, right_most](const DataPoint &data_point) {
+      if(precision_p)
+        {
 
-                       // FIXME: unbelievable behaviour: when building in
-                       // release mode this code, under i386 (but not x86_64),
-                       // this code fails if the following%S statement is
-                       // missing.
+          // FIXME: unbelievable behaviour: when building in
+          // release mode this code, under i386 (but not x86_64),
+          // this code fails if the following%S statement is
+          // missing.
 
-                       // std::cout << std::setprecision(10)
-                       //<< "Testing data_point.x: " << data_point.x
-                       //<< std::endl;
+          // std::cout << std::setprecision(10)
+          //<< "Testing data_point.x: " << data_point.x
+          //<< std::endl;
 
-                       // For this reason I had to deactivate the related tests
-                       // for i386 in tests/test_trace.cpp
+          // For this reason I had to deactivate the related tests
+          // for i386 in tests/test_trace.cpp
 
-                       double diff_to_left_most  = data_point.x - left_most;
-                       double diff_to_right_most = data_point.x - right_most;
+          double diff_to_left_most  = data_point.x - left_most;
+          double diff_to_right_most = data_point.x - right_most;
 
-                       // std::cout << std::setprecision(10)
-                       //<< "diff_to_left_most: " << diff_to_left_most
-                       //<< " diff_to_right_most: " << diff_to_right_most <<
-                       // std::endl;
+          // std::cout << std::setprecision(10)
+          //<< "diff_to_left_most: " << diff_to_left_most
+          //<< " diff_to_right_most: " << diff_to_right_most <<
+          // std::endl;
 
-                       // if(diff_to_left_most > 0)
-                       //{
-                       // std::cout << std::setprecision(10)
-                       //<< " point is right of left_most: " <<
-                       // diff_to_left_most
-                       //<< std::endl;
-                       //}
-                       // if(diff_to_left_most < 0)
-                       //{
-                       // std::cout << std::setprecision(10)
-                       //<< "point is left of left_most: " << diff_to_left_most
-                       //<< std::endl;
-                       //}
-                       // if(!diff_to_left_most)
-                       //{
-                       // std::cout << std::setprecision(10)
-                       //<< "point is spot on left_most: " << diff_to_left_most
-                       //<< std::endl;
-                       //}
+          // if(diff_to_left_most > 0)
+          //{
+          // std::cout << std::setprecision(10)
+          //<< " point is right of left_most: " <<
+          // diff_to_left_most
+          //<< std::endl;
+          //}
+          // if(diff_to_left_most < 0)
+          //{
+          // std::cout << std::setprecision(10)
+          //<< "point is left of left_most: " << diff_to_left_most
+          //<< std::endl;
+          //}
+          // if(!diff_to_left_most)
+          //{
+          // std::cout << std::setprecision(10)
+          //<< "point is spot on left_most: " << diff_to_left_most
+          //<< std::endl;
+          //}
 
-                       // if(diff_to_right_most > 0)
-                       //{
-                       // std::cout << std::setprecision(10)
-                       //<< "point is right of right_most: " <<
-                       // diff_to_right_most
-                       //<< std::endl;
-                       //}
-                       // if(diff_to_right_most < 0)
-                       //{
-                       // std::cout << std::setprecision(10)
-                       //<< "point is left or of right_most: "
-                       //<< diff_to_right_most << std::endl;
-                       //}
-                       // if(!diff_to_right_most)
-                       //{
-                       // std::cout << std::setprecision(10)
-                       //<< "point is spot on right_most: " <<
-                       // diff_to_right_most
-                       //<< std::endl;
-                       //}
+          // if(diff_to_right_most > 0)
+          //{
+          // std::cout << std::setprecision(10)
+          //<< "point is right of right_most: " <<
+          // diff_to_right_most
+          //<< std::endl;
+          //}
+          // if(diff_to_right_most < 0)
+          //{
+          // std::cout << std::setprecision(10)
+          //<< "point is left or of right_most: "
+          //<< diff_to_right_most << std::endl;
+          //}
+          // if(!diff_to_right_most)
+          //{
+          // std::cout << std::setprecision(10)
+          //<< "point is spot on right_most: " <<
+          // diff_to_right_most
+          //<< std::endl;
+          //}
 
-                       if(diff_to_left_most >= 0 && diff_to_right_most <= 0)
-                         {
-                           // std::cout << "The point is inside the range,
-                           // should return true."
-                           //<< std::endl;
-                           return true;
-                         }
-                       else
-                         {
-                           // std::cout
-                           //<< "The point is outside the range, should return
-                           // false."
-                           //<< std::endl;
-                           return false;
-                         }
-                     }
-                   else
-                     {
-                       return (data_point.x == value);
-                     }
-                 });
+          if(diff_to_left_most >= 0 && diff_to_right_most <= 0)
+            {
+              // std::cout << "The point is inside the range,
+              // should return true."
+              //<< std::endl;
+              return true;
+            }
+          else
+            {
+              // std::cout
+              //<< "The point is outside the range, should return
+              // false."
+              //<< std::endl;
+              return false;
+            }
+        }
+      else
+        {
+          return (data_point.x == value);
+        }
+    });
 
   if(iterator != end())
     {
@@ -1155,4 +1187,21 @@ Trace::filter(const FilterInterface &filter)
   return filter.filter(*this);
 }
 
+QJsonObject
+Trace::toJsonObject(const QString &x_label, const QString &y_label) const
+{
+  QJsonObject json_trace;
+  QJsonArray x_arr;
+  QJsonArray y_arr;
+
+  for(auto &&data_point : *this)
+    {
+      x_arr.push_back(data_point.x);
+      y_arr.push_back(data_point.y);
+    }
+  json_trace.insert(x_label, x_arr);
+  json_trace.insert(y_label, y_arr);
+
+  return json_trace;
+}
 } // namespace pappso
