@@ -23,7 +23,6 @@
 
 /////////////////////// StdLib includes
 #include <cmath>
-#include <iomanip>
 
 
 /////////////////////// Qt includes
@@ -38,7 +37,7 @@
 #include "utils.h"
 #include "types.h"
 #include "pappsomspp/core/exception/exceptionnotfound.h"
-#include "trace/trace.h"
+#include "pappsomspp/core/mzrange.h"
 
 
 namespace pappso
