@@ -47,7 +47,7 @@ namespace pappso
 TimsData::TimsData(QDir timsDataDirectory) : m_timsDataDirectory(timsDataDirectory)
 {
 
-  qDebug() << "Start of construction of TimsData";
+  // qDebug() << "Start of construction of TimsData";
   mpa_mzCalibrationStore = new MzCalibrationStore();
   if(!m_timsDataDirectory.exists())
     {
