@@ -35,32 +35,26 @@
 namespace pappso
 {
 
-TimsFrame::XicComputeStructure::XicComputeStructure(
-  const TimsFrame *fram_p, const XicCoordTims &xic_struct)
+TimsFrame::XicComputeStructure::XicComputeStructure(const TimsFrame *fram_p,
+                                                    const XicCoordTims &xic_struct)
 {
   xic_ptr = xic_struct.xicSptr.get();
 
   mobilityIndexBegin = xic_struct.scanNumBegin;
   mobilityIndexEnd   = xic_struct.scanNumEnd;
-  mzIndexLowerBound =
-    fram_p->getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(
-      xic_struct.mzRange.lower()); // convert mz to raw digitizer value
+  mzIndexLowerBound  = fram_p->getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(
+    xic_struct.mzRange.lower()); // convert mz to raw digitizer value
   mzIndexUpperBound =
-    fram_p->getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(
-      xic_struct.mzRange.upper());
+    fram_p->getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(xic_struct.mzRange.upper());
   tmpIntensity = 0;
 }
 
-TimsFrame::TimsFrame(std::size_t timsId, quint32 scanNum)
-  : TimsFrameBase(timsId, scanNum)
+TimsFrame::TimsFrame(std::size_t timsId, quint32 scanNum) : TimsFrameBase(timsId, scanNum)
 {
   // m_timsDataFrame.resize(10);
 }
 
-TimsFrame::TimsFrame(std::size_t timsId,
-                     quint32 scanNum,
-                     char *p_bytes,
-                     std::size_t len)
+TimsFrame::TimsFrame(std::size_t timsId, quint32 scanNum, char *p_bytes, std::size_t len)
   : TimsFrameBase(timsId, scanNum)
 {
   // langella@themis:~/developpement/git/bruker/cbuild$
@@ -79,11 +73,10 @@ TimsFrame::TimsFrame(std::size_t timsId,
       if(m_scanCount == 0)
         {
 
-          throw pappso::PappsoException(
-            QObject::tr("TimsFrame::TimsFrame(%1,%2,nullptr,%3) FAILED")
-              .arg(m_frameId)
-              .arg(m_scanCount)
-              .arg(len));
+          throw pappso::PappsoException(QObject::tr("TimsFrame::TimsFrame(%1,%2,nullptr,%3) FAILED")
+                                          .arg(m_frameId)
+                                          .arg(m_scanCount)
+                                          .arg(len));
         }
     }
 }
@@ -104,8 +97,7 @@ TimsFrame::unshufflePacket(const char *src)
   quint64 len = m_binaryData.size();
   if(len % 4 != 0)
     {
-      throw pappso::PappsoException(
-        QObject::tr("TimsFrame::unshufflePacket error: len % 4 != 0"));
+      throw pappso::PappsoException(QObject::tr("TimsFrame::unshufflePacket error: len % 4 != 0"));
     }
 
   quint64 nb_uint4 = len / 4;
@@ -182,10 +174,8 @@ TimsFrame::getScanTofIndexList(std::size_t scanNum) const
   qint32 previous = -1;
   for(std::size_t i = 0; i < scan_tof.size(); i++)
     {
-      scan_tof[i] =
-        (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8))) +
-        previous;
-      previous = scan_tof[i];
+      scan_tof[i] = (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8))) + previous;
+      previous    = scan_tof[i];
     }
   // qDebug();
   return scan_tof;
@@ -207,8 +197,7 @@ TimsFrame::getScanIntensityList(std::size_t scanNum) const
 
   for(std::size_t i = 0; i < scan_intensities.size(); i++)
     {
-      scan_intensities[i] =
-        (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8) + 4));
+      scan_intensities[i] = (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8) + 4));
     }
   // qDebug();
   return scan_intensities;
@@ -234,12 +223,9 @@ TimsFrame::cumulateScanIntensities(std::size_t scanNum) const
 
   for(std::size_t i = 0; i < size; i++)
     {
-      quint32 x =
-        (*(quint32 *)((m_binaryData.constData() + (offset * 4) + (i * 8))) +
-         previous);
+      quint32 x = (*(quint32 *)((m_binaryData.constData() + (offset * 4) + (i * 8))) + previous);
 
-      quint32 y =
-        (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8) + 4));
+      quint32 y = (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8) + 4));
 
       previous = x;
 
@@ -301,8 +287,7 @@ TimsFrame::cumulateScanRangeIntensities(std::size_t mobility_scan_begin,
 
 
 void
-TimsFrame::cumulateScan(std::size_t scanNum,
-                        TimsDataFastMap &accumulate_into) const
+TimsFrame::cumulateScan(std::size_t scanNum, TimsDataFastMap &accumulate_into) const
 {
   // qDebug();
 
@@ -319,11 +304,9 @@ TimsFrame::cumulateScan(std::size_t scanNum,
   qint32 previous = -1;
   for(std::size_t i = 0; i < scan_size; i++)
     {
-      quint32 x = (*(quint32 *)((m_binaryData.constData() + (scan_offset * 4) +
-                                 (i * 8))) +
-                   previous);
-      quint32 y = (*(quint32 *)(m_binaryData.constData() + (scan_offset * 4) +
-                                (i * 8) + 4));
+      quint32 x =
+        (*(quint32 *)((m_binaryData.constData() + (scan_offset * 4) + (i * 8))) + previous);
+      quint32 y = (*(quint32 *)(m_binaryData.constData() + (scan_offset * 4) + (i * 8) + 4));
 
       previous = x;
       // qDebug() << "x=" << x << " y=" << y;
@@ -353,9 +336,8 @@ TimsFrame::cumulateScan2(std::size_t scanNum,
 
   for(std::size_t i = 0; i < scan_size; i++)
     {
-      quint32 x = (*(quint32 *)((m_binaryData.constData() + (scan_offset * 4) +
-                                 (i * 8))) +
-                   previous);
+      quint32 x =
+        (*(quint32 *)((m_binaryData.constData() + (scan_offset * 4) + (i * 8))) + previous);
 
       previous = x;
 
@@ -373,8 +355,7 @@ TimsFrame::cumulateScan2(std::size_t scanNum,
 
       // qDebug() << "TOF index in range, x:" << x;
 
-      quint32 y = (*(quint32 *)(m_binaryData.constData() + (scan_offset * 4) +
-                                (i * 8) + 4));
+      quint32 y = (*(quint32 *)(m_binaryData.constData() + (scan_offset * 4) + (i * 8) + 4));
 
       accumulate_into.accumulateIntensity(x, y);
     }
@@ -395,8 +376,7 @@ TimsFrame::cumulateScansToTrace(std::size_t mobility_scan_begin,
     {
       if(m_binaryData.size() == 0)
         return new_trace;
-      TimsDataFastMap &raw_spectrum =
-        TimsDataFastMap::getTimsDataFastMapInstance();
+      TimsDataFastMap &raw_spectrum = TimsDataFastMap::getTimsDataFastMapInstance();
       raw_spectrum.clear();
       // double local_accumulationTime = 0;
 
@@ -416,16 +396,15 @@ TimsFrame::cumulateScansToTrace(std::size_t mobility_scan_begin,
       pappso::DataPoint data_point_cumul;
 
 
-      MzCalibrationInterface *mz_calibration_p =
-        getMzCalibrationInterfaceSPtr().get();
+      MzCalibrationInterface *mz_calibration_p = getMzCalibrationInterfaceSPtr().get();
 
 
       for(quint32 tof_index : raw_spectrum.getTofIndexList())
         {
           data_point_cumul.x = mz_calibration_p->getMzFromTofIndex(tof_index);
           // normalization
-          data_point_cumul.y = raw_spectrum.readIntensity(tof_index) *
-                               ((double)100.0 / m_acqDurationInMilliseconds);
+          data_point_cumul.y =
+            raw_spectrum.readIntensity(tof_index) * ((double)100.0 / m_acqDurationInMilliseconds);
           new_trace.push_back(data_point_cumul);
         }
       new_trace.sortX();
@@ -435,8 +414,7 @@ TimsFrame::cumulateScansToTrace(std::size_t mobility_scan_begin,
 
   catch(std::exception &error)
     {
-      qDebug() << QString(
-                    "Failure in TimsFrame::cumulateScanToTrace %1 to %2 :\n %3")
+      qDebug() << QString("Failure in TimsFrame::cumulateScanToTrace %1 to %2 :\n %3")
                     .arg(mobility_scan_begin, mobility_scan_end)
                     .arg(error.what());
     }
@@ -444,12 +422,11 @@ TimsFrame::cumulateScansToTrace(std::size_t mobility_scan_begin,
 }
 
 Trace
-TimsFrame::combineScansToTraceWithDowngradedMzResolution(
-  std::size_t mz_index_merge_window,
-  std::size_t mobility_scan_begin,
-  std::size_t mobility_scan_end,
-  quint32 &mz_minimum_index_out,
-  quint32 &mz_maximum_index_out) const
+TimsFrame::combineScansToTraceWithDowngradedMzResolution(std::size_t mz_index_merge_window,
+                                                         std::size_t mobility_scan_begin,
+                                                         std::size_t mobility_scan_end,
+                                                         quint32 &mz_minimum_index_out,
+                                                         quint32 &mz_maximum_index_out) const
 {
   // qDebug();
 
@@ -466,8 +443,7 @@ TimsFrame::combineScansToTraceWithDowngradedMzResolution(
       // Allocate a map for (TOF,intensity) pairs to
       // accumulate ion mobility scans.
 
-      TimsDataFastMap &raw_spectrum =
-        TimsDataFastMap::getTimsDataFastMapInstance();
+      TimsDataFastMap &raw_spectrum = TimsDataFastMap::getTimsDataFastMapInstance();
       raw_spectrum.clear();
       // double local_accumulationTime = 0;
 
@@ -488,8 +464,7 @@ TimsFrame::combineScansToTraceWithDowngradedMzResolution(
 
       pappso::DataPoint data_point_cumul;
 
-      MzCalibrationInterface *mz_calibration_p =
-        getMzCalibrationInterfaceSPtr().get();
+      MzCalibrationInterface *mz_calibration_p = getMzCalibrationInterfaceSPtr().get();
 
       // If the caller asks that m/z values be binned larger than they are,
       // ask that the m/z raw map be reduced in resolution.
@@ -516,8 +491,8 @@ TimsFrame::combineScansToTraceWithDowngradedMzResolution(
           data_point_cumul.x = mz_calibration_p->getMzFromTofIndex(tof_index);
 
           // Normalization
-          data_point_cumul.y = raw_spectrum.readIntensity(tof_index) *
-                               ((double)100.0 / m_acqDurationInMilliseconds);
+          data_point_cumul.y =
+            raw_spectrum.readIntensity(tof_index) * ((double)100.0 / m_acqDurationInMilliseconds);
 
           // Finally make the data point a new Trace point.
           new_trace.push_back(data_point_cumul);
@@ -535,8 +510,7 @@ TimsFrame::combineScansToTraceWithDowngradedMzResolution(
     }
   catch(std::exception &error)
     {
-      qDebug() << QString(
-                    "Failure in TimsFrame::cumulateScanToTrace %1 to %2 :\n %3")
+      qDebug() << QString("Failure in TimsFrame::cumulateScanToTrace %1 to %2 :\n %3")
                     .arg(mobility_scan_begin, mobility_scan_end)
                     .arg(error.what());
     }
@@ -548,14 +522,13 @@ TimsFrame::combineScansToTraceWithDowngradedMzResolution(
 
 
 Trace
-TimsFrame::combineScansToTraceWithDowngradedMzResolution2(
-  std::size_t mz_index_merge_window,
-  double mz_range_begin,
-  double mz_range_end,
-  std::size_t mobility_scan_begin,
-  std::size_t mobility_scan_end,
-  quint32 &mz_minimum_index_out,
-  quint32 &mz_maximum_index_out) const
+TimsFrame::combineScansToTraceWithDowngradedMzResolution2(std::size_t mz_index_merge_window,
+                                                          double mz_range_begin,
+                                                          double mz_range_end,
+                                                          std::size_t mobility_scan_begin,
+                                                          std::size_t mobility_scan_end,
+                                                          quint32 &mz_minimum_index_out,
+                                                          quint32 &mz_maximum_index_out) const
 {
   // qDebug() << "Calling cumulateScansToTraceMzDownResolution2 for both mz and "
   //             "im ranges accounting.";
@@ -573,16 +546,14 @@ TimsFrame::combineScansToTraceWithDowngradedMzResolution2(
       // Allocate a map for (TOF index,intensity) pairs to
       // accumulate ion mobility scans.
 
-      TimsDataFastMap &raw_spectrum =
-        TimsDataFastMap::getTimsDataFastMapInstance();
+      TimsDataFastMap &raw_spectrum = TimsDataFastMap::getTimsDataFastMapInstance();
       raw_spectrum.clear();
       // double local_accumulationTime = 0;
 
       std::size_t mobility_scan_max = mobility_scan_end + 1;
 
       quint32 tof_index_for_mz_range_begin =
-        getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(
-          mz_range_begin);
+        getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(mz_range_begin);
       quint32 tof_index_for_mz_range_end =
         getMzCalibrationInterfaceSPtr().get()->getTofIndexFromMz(mz_range_end);
 
@@ -591,15 +562,12 @@ TimsFrame::combineScansToTraceWithDowngradedMzResolution2(
       // qDebug() << "TOF index for mz range end:"
       //          << tof_index_for_mz_range_end;
 
-      for(std::size_t iter = mobility_scan_begin; iter < mobility_scan_max;
-          iter++)
+      for(std::size_t iter = mobility_scan_begin; iter < mobility_scan_max; iter++)
         {
           // qDebug() << "Going to cumulate currently iterated mobility scan:"
           // << iter;
-          cumulateScan2(iter,
-                        raw_spectrum,
-                        tof_index_for_mz_range_begin,
-                        tof_index_for_mz_range_end);
+          cumulateScan2(
+            iter, raw_spectrum, tof_index_for_mz_range_begin, tof_index_for_mz_range_end);
           // qDebug() << "Done cumulating currently iterated mobility scan:" <<
           // i;
 
@@ -610,8 +578,7 @@ TimsFrame::combineScansToTraceWithDowngradedMzResolution2(
 
       pappso::DataPoint data_point_cumul;
 
-      MzCalibrationInterface *mz_calibration_p =
-        getMzCalibrationInterfaceSPtr().get();
+      MzCalibrationInterface *mz_calibration_p = getMzCalibrationInterfaceSPtr().get();
 
       // If the caller asks that m/z values be binned larger than they are,
       // ask that the m/z raw map be reduced in resolution.
@@ -638,8 +605,7 @@ TimsFrame::combineScansToTraceWithDowngradedMzResolution2(
           data_point_cumul.x = mz_calibration_p->getMzFromTofIndex(tof_index);
 
           // Normalization
-          data_point_cumul.y =
-            intensity * ((double)100.0 / m_acqDurationInMilliseconds);
+          data_point_cumul.y = intensity * ((double)100.0 / m_acqDurationInMilliseconds);
 
           // Finally make the data point a new Trace point.
           new_trace.push_back(data_point_cumul);
@@ -657,8 +623,7 @@ TimsFrame::combineScansToTraceWithDowngradedMzResolution2(
     }
   catch(std::exception &error)
     {
-      qDebug() << QString(
-                    "Failure in TimsFrame::cumulateScanToTrace %1 to %2 :\n %3")
+      qDebug() << QString("Failure in TimsFrame::cumulateScanToTrace %1 to %2 :\n %3")
                     .arg(mobility_scan_begin, mobility_scan_end)
                     .arg(error.what());
     }
@@ -759,8 +724,7 @@ TimsFrame::getMassSpectrumSPtr(std::size_t scanNum) const
 
   // qDebug();
 
-  pappso::MassSpectrumSPtr mass_spectrum_sptr =
-    std::make_shared<pappso::MassSpectrum>();
+  pappso::MassSpectrumSPtr mass_spectrum_sptr = std::make_shared<pappso::MassSpectrum>();
   // std::vector<DataPoint>
 
   if(m_binaryData.size() == 0)
@@ -772,8 +736,7 @@ TimsFrame::getMassSpectrumSPtr(std::size_t scanNum) const
 
   std::size_t offset = getScanOffset(scanNum);
 
-  MzCalibrationInterface *mz_calibration_p =
-    getMzCalibrationInterfaceSPtr().get();
+  MzCalibrationInterface *mz_calibration_p = getMzCalibrationInterfaceSPtr().get();
 
 
   qint32 previous = -1;
@@ -782,11 +745,8 @@ TimsFrame::getMassSpectrumSPtr(std::size_t scanNum) const
   DataPoint data_point;
   for(std::size_t i = 0; i < size; i++)
     {
-      tof_index =
-        (*(quint32 *)((m_binaryData.constData() + (offset * 4) + (i * 8))) +
-         previous);
-      data_point.y =
-        (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8) + 4));
+      tof_index    = (*(quint32 *)((m_binaryData.constData() + (offset * 4) + (i * 8))) + previous);
+      data_point.y = (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8) + 4));
 
       // intensity normalization
       data_point.y *= 100.0 / m_acqDurationInMilliseconds;
@@ -826,16 +786,14 @@ TimsFrame::getMobilityScan(std::size_t scanNum,
     {
       // qDebug() << "m/z range is requested.";
 
-      mz_index_begin =
-        msp_mzCalibration.get()->getTofIndexFromMz(mz_range_begin);
-      mz_index_end = msp_mzCalibration.get()->getTofIndexFromMz(mz_range_end);
+      mz_index_begin = msp_mzCalibration.get()->getTofIndexFromMz(mz_range_begin);
+      mz_index_end   = msp_mzCalibration.get()->getTofIndexFromMz(mz_range_end);
     }
 
   // qDebug() << "After conversion of mz indices, mz_index_begin:"
   //          << mz_index_begin << "mz_index_end;" << mz_index_end;
 
-  auto raw_spectrum =
-    getRawValuePairList(scanNum, mz_index_begin, mz_index_end);
+  auto raw_spectrum = getRawValuePairList(scanNum, mz_index_begin, mz_index_end);
 
   // qDebug() << " raw_spectrum.size();" << raw_spectrum.size();
 
@@ -843,8 +801,8 @@ TimsFrame::getMobilityScan(std::size_t scanNum,
     {
       // qDebug() << "mz_index_merge_window;=" << mz_index_merge_window
       //          << " raw_spectrum.size()=" << raw_spectrum.size();
-      raw_spectrum = downgradeResolutionOfTofIndexIntensityPairList(
-        mz_index_merge_window, raw_spectrum);
+      raw_spectrum =
+        downgradeResolutionOfTofIndexIntensityPairList(mz_index_merge_window, raw_spectrum);
     }
 
   if(raw_spectrum.size() > 0)
@@ -854,9 +812,9 @@ TimsFrame::getMobilityScan(std::size_t scanNum,
 
       for(auto &&element : raw_spectrum)
         {
-          spectrum.push_back(DataPoint(
-            msp_mzCalibration.get()->getMzFromTofIndex(element.tof_index),
-            static_cast<double>(element.intensity_index)));
+          spectrum.push_back(
+            DataPoint(msp_mzCalibration.get()->getMzFromTofIndex(element.tof_index),
+                      static_cast<double>(element.intensity_index)));
 
           // intensity normalization
           spectrum.back().y *= 100.0 / m_acqDurationInMilliseconds;
@@ -867,10 +825,9 @@ TimsFrame::getMobilityScan(std::size_t scanNum,
 }
 
 void
-TimsFrame::extractTimsXicListInRtRange(
-  std::vector<XicCoordTims *>::iterator &itXicListbegin,
-  std::vector<XicCoordTims *>::iterator &itXicListend,
-  Enums::XicExtractMethod method) const
+TimsFrame::extractTimsXicListInRtRange(std::vector<XicCoordTims *>::iterator &itXicListbegin,
+                                       std::vector<XicCoordTims *>::iterator &itXicListend,
+                                       Enums::XicExtractMethod method) const
 {
   // qDebug() << std::distance(itXicListbegin, itXicListend);
 
@@ -909,9 +866,8 @@ TimsFrame::extractTimsXicListInRtRange(
         }
     }
   std::sort(unique_scan_num_list.begin(), unique_scan_num_list.end());
-  auto it_scan_num_end =
-    std::unique(unique_scan_num_list.begin(), unique_scan_num_list.end());
-  auto it_scan_num = unique_scan_num_list.begin();
+  auto it_scan_num_end = std::unique(unique_scan_num_list.begin(), unique_scan_num_list.end());
+  auto it_scan_num     = unique_scan_num_list.begin();
 
   while(it_scan_num != it_scan_num_end)
     {
@@ -924,9 +880,8 @@ TimsFrame::extractTimsXicListInRtRange(
             {
               if(method == Enums::XicExtractMethod::max)
                 {
-                  tmp_xic_struct.tmpIntensity +=
-                    ms_spectrum.get()->maxY(tmp_xic_struct.mzIndexLowerBound,
-                                            tmp_xic_struct.mzIndexUpperBound);
+                  tmp_xic_struct.tmpIntensity += ms_spectrum.get()->maxY(
+                    tmp_xic_struct.mzIndexLowerBound, tmp_xic_struct.mzIndexUpperBound);
 
                   // qDebug() << "tmp_xic_struct.tmpIntensity="
                   //          << tmp_xic_struct.tmpIntensity;
@@ -934,9 +889,8 @@ TimsFrame::extractTimsXicListInRtRange(
               else
                 {
                   // sum
-                  tmp_xic_struct.tmpIntensity +=
-                    ms_spectrum.get()->sumY(tmp_xic_struct.mzIndexLowerBound,
-                                            tmp_xic_struct.mzIndexUpperBound);
+                  tmp_xic_struct.tmpIntensity += ms_spectrum.get()->sumY(
+                    tmp_xic_struct.mzIndexLowerBound, tmp_xic_struct.mzIndexUpperBound);
 
                   // qDebug() << "tmp_xic_struct.tmpIntensity="
                   //          << tmp_xic_struct.tmpIntensity;
@@ -952,8 +906,7 @@ TimsFrame::extractTimsXicListInRtRange(
         {
           // qDebug() << tmp_xic_struct.xic_ptr;
 
-          tmp_xic_struct.xic_ptr->push_back(
-            {m_rtInSeconds, tmp_xic_struct.tmpIntensity});
+          tmp_xic_struct.xic_ptr->push_back({m_rtInSeconds, tmp_xic_struct.tmpIntensity});
         }
     }
 
@@ -983,8 +936,7 @@ TimsFrame::getRawTraceSPtr(std::size_t scanNum) const
   for(std::size_t i = 0; i < size; i++)
     {
       DataPoint data_point(
-        (*(quint32 *)((m_binaryData.constData() + (offset * 4) + (i * 8))) +
-         previous),
+        (*(quint32 *)((m_binaryData.constData() + (offset * 4) + (i * 8))) + previous),
         (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8) + 4)));
 
       // intensity normalization
@@ -1024,10 +976,8 @@ TimsFrame::getRawValuePairList(std::size_t scanNum,
 
       // qDebug() << i;
       TimsFrame::TofIndexIntensityPair raw_value_pair(
-        {(*(quint32 *)((m_binaryData.constData() + (offset * 4) + (i * 8))) +
-          previous),
-         (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8) +
-                       4))});
+        {(*(quint32 *)((m_binaryData.constData() + (offset * 4) + (i * 8))) + previous),
+         (*(quint32 *)(m_binaryData.constData() + (offset * 4) + (i * 8) + 4))});
 
       previous = raw_value_pair.tof_index;
       if(raw_value_pair.tof_index < accepted_tof_index_range_begin)
