@@ -68,8 +68,7 @@ BaseColorMapPlotWidget::BaseColorMapPlotWidget(QWidget *parent,
 }
 
 
-BaseColorMapPlotWidget::BaseColorMapPlotWidget(QWidget *parent)
-  : BasePlotWidget(parent, "x", "y")
+BaseColorMapPlotWidget::BaseColorMapPlotWidget(QWidget *parent) : BasePlotWidget(parent, "x", "y")
 {
   // Do not call createAllAncillaryItems() in this base class because all the
   // items will have been created *before* the addition of plots and then the
@@ -111,8 +110,7 @@ BaseColorMapPlotWidget::~BaseColorMapPlotWidget()
 
 
 void
-BaseColorMapPlotWidget::setColorMapPlotConfig(
-  const ColorMapPlotConfig &color_map_config)
+BaseColorMapPlotWidget::setColorMapPlotConfig(const ColorMapPlotConfig &color_map_config)
 {
   m_colorMapPlotConfig = color_map_config;
 }
@@ -142,8 +140,7 @@ BaseColorMapPlotWidget::addColorMap(
   // color_map_plot_config.toString();
 
   if(!color.isValid())
-    throw PappsoException(
-      QString("The color to be used for the plot graph is invalid."));
+    throw PappsoException(QString("The color to be used for the plot graph is invalid."));
 
   QCPColorMap *color_map_p = new QCPColorMap(xAxis, yAxis);
 
@@ -180,13 +177,12 @@ BaseColorMapPlotWidget::addColorMap(
   // Connect the signal of selection change so that we can re-emit it for the
   // widget that is using *this widget.
 
-  connect(color_map_p,
-          static_cast<void (QCPAbstractPlottable::*)(bool)>(
-            &QCPAbstractPlottable::selectionChanged),
-          [this, color_map_p]() {
-            emit plottableSelectionChangedSignal(color_map_p,
-                                                 color_map_p->selected());
-          });
+  connect(
+    color_map_p,
+    static_cast<void (QCPAbstractPlottable::*)(bool)>(&QCPAbstractPlottable::selectionChanged),
+    [this, color_map_p]() {
+      emit plottableSelectionChangedSignal(color_map_p, color_map_p->selected());
+    });
 
   // qDebug() << "Configuring the color map with this config:"
   //<< color_map_plot_config.toString();
@@ -194,10 +190,9 @@ BaseColorMapPlotWidget::addColorMap(
   color_map_p->data()->setSize(color_map_plot_config.keyCellCount,
                                color_map_plot_config.mzCellCount);
 
-  color_map_p->data()->setRange(QCPRange(color_map_plot_config.minKeyValue,
-                                         color_map_plot_config.maxKeyValue),
-                                QCPRange(color_map_plot_config.minMzValue,
-                                         color_map_plot_config.maxMzValue));
+  color_map_p->data()->setRange(
+    QCPRange(color_map_plot_config.minKeyValue, color_map_plot_config.maxKeyValue),
+    QCPRange(color_map_plot_config.minMzValue, color_map_plot_config.maxMzValue));
   color_map_p->data()->fill(0.0);
 
   // We have now to fill the color map.
@@ -284,15 +279,13 @@ BaseColorMapPlotWidget::addColorMap(
 }
 
 QCPColorMap *
-BaseColorMapPlotWidget::addColorMap(
-  const TimsFrame &tims_frame,
-  const ColorMapPlotConfig color_map_plot_config,
-  const QColor &color)
+BaseColorMapPlotWidget::addColorMap(const TimsFrame &tims_frame,
+                                    const ColorMapPlotConfig color_map_plot_config,
+                                    const QColor &color)
 {
   qDebug();
   if(!color.isValid())
-    throw PappsoException(
-      QString("The color to be used for the plot graph is invalid."));
+    throw PappsoException(QString("The color to be used for the plot graph is invalid."));
 
   QCPColorMap *color_map_p = new QCPColorMap(xAxis, yAxis);
 
@@ -331,13 +324,12 @@ BaseColorMapPlotWidget::addColorMap(
   // Connect the signal of selection change so that we can re-emit it for the
   // widget that is using *this widget.
 
-  connect(color_map_p,
-          static_cast<void (QCPAbstractPlottable::*)(bool)>(
-            &QCPAbstractPlottable::selectionChanged),
-          [this, color_map_p]() {
-            emit plottableSelectionChangedSignal(color_map_p,
-                                                 color_map_p->selected());
-          });
+  connect(
+    color_map_p,
+    static_cast<void (QCPAbstractPlottable::*)(bool)>(&QCPAbstractPlottable::selectionChanged),
+    [this, color_map_p]() {
+      emit plottableSelectionChangedSignal(color_map_p, color_map_p->selected());
+    });
 
   // qDebug() << "Configuring the color map with this config:"
   //<< color_map_plot_config.toString();
@@ -345,10 +337,9 @@ BaseColorMapPlotWidget::addColorMap(
   color_map_p->data()->setSize(color_map_plot_config.keyCellCount,
                                color_map_plot_config.mzCellCount);
 
-  color_map_p->data()->setRange(QCPRange(color_map_plot_config.minKeyValue,
-                                         color_map_plot_config.maxKeyValue),
-                                QCPRange(color_map_plot_config.minMzValue,
-                                         color_map_plot_config.maxMzValue));
+  color_map_p->data()->setRange(
+    QCPRange(color_map_plot_config.minKeyValue, color_map_plot_config.maxKeyValue),
+    QCPRange(color_map_plot_config.minMzValue, color_map_plot_config.maxMzValue));
   color_map_p->data()->fill(0.0);
   // double max_intensity = 0;
   qDebug();
@@ -356,9 +347,8 @@ BaseColorMapPlotWidget::addColorMap(
   std::size_t number_of_scans = tims_frame.getTotalNumberOfScans();
   for(std::size_t i = 0; i < number_of_scans; i++)
     {
-      std::vector<quint32> tof_index_vector = tims_frame.getScanTofIndexList(i);
-      std::vector<quint32> intensity_index_vector =
-        tims_frame.getScanIntensityList(i);
+      std::vector<quint32> tof_index_vector       = tims_frame.getScanTofIndexList(i);
+      std::vector<quint32> intensity_index_vector = tims_frame.getScanIntensityList(i);
 
 
       // The first value is the key and the second value is the MapTrace into
@@ -477,8 +467,7 @@ BaseColorMapPlotWidget::transposeAxes()
   //<< "Value at cell 80,650:" << origData->cell(80,650);
 
   // Transposed map.
-  QCPColorMapData *newData =
-    new QCPColorMapData(valueSize, keySize, valueRange, keyRange);
+  QCPColorMapData *newData = new QCPColorMapData(valueSize, keySize, valueRange, keyRange);
 
   for(int iter = 0; iter < keySize; ++iter)
     {
@@ -500,7 +489,7 @@ BaseColorMapPlotWidget::transposeAxes()
 
   // Now we need to invert the labels and data kinds.
 
-  Enums::DataKind temp_data_kind            = m_colorMapPlotConfig.xAxisDataKind;
+  Enums::DataKind temp_data_kind     = m_colorMapPlotConfig.xAxisDataKind;
   m_colorMapPlotConfig.xAxisDataKind = m_colorMapPlotConfig.yAxisDataKind;
   m_colorMapPlotConfig.yAxisDataKind = temp_data_kind;
 
@@ -561,18 +550,15 @@ BaseColorMapPlotWidget::zAxisScaleToLog10()
 
   // But we need to reset these two values to be able to update them using
   // std::min() and std::max() below.
-  new_color_map_plot_config.setOrigAndLastMinZValue(
-    std::numeric_limits<double>::max());
+  new_color_map_plot_config.setOrigAndLastMinZValue(std::numeric_limits<double>::max());
 
-  new_color_map_plot_config.setOrigAndLastMaxZValue(
-    std::numeric_limits<double>::min());
+  new_color_map_plot_config.setOrigAndLastMaxZValue(std::numeric_limits<double>::min());
 
   // qDebug() << "new_color_map_plot_config"
   //<< new_color_map_plot_config.toString();
 
   // Log-ified heat map.
-  QCPColorMapData *new_map_data =
-    new QCPColorMapData(keySize, valueSize, keyRange, valueRange);
+  QCPColorMapData *new_map_data = new QCPColorMapData(keySize, valueSize, keyRange, valueRange);
 
   // qDebug() << "Starting iteration in the color map.";
 
@@ -648,8 +634,7 @@ BaseColorMapPlotWidget::zAxisScaleToLog10()
 }
 
 void
-BaseColorMapPlotWidget::zAxisFilterLowPassPercentage(
-  double threshold_percentage)
+BaseColorMapPlotWidget::zAxisFilterLowPassPercentage(double threshold_percentage)
 {
   // This filter allows all the values smaller than a threshold to remain
   // unchanged. Instead, all the values above the threshold will be reset to
@@ -691,8 +676,7 @@ BaseColorMapPlotWidget::zAxisFilterLowPassPercentage(
   new_color_map_plot_config.lastMaxZValue = std::numeric_limits<double>::min();
 
   // Filtered
-  QCPColorMapData *new_map_data =
-    new QCPColorMapData(keySize, valueSize, keyRange, valueRange);
+  QCPColorMapData *new_map_data = new QCPColorMapData(keySize, valueSize, keyRange, valueRange);
 
   for(int iter = 0; iter < keySize; ++iter)
     {
@@ -790,8 +774,7 @@ BaseColorMapPlotWidget::zAxisFilterLowPassThreshold(double threshold)
   new_color_map_plot_config.lastMaxZValue = std::numeric_limits<double>::min();
 
   // Filtered
-  QCPColorMapData *new_map_data =
-    new QCPColorMapData(keySize, valueSize, keyRange, valueRange);
+  QCPColorMapData *new_map_data = new QCPColorMapData(keySize, valueSize, keyRange, valueRange);
 
   for(int iter = 0; iter < keySize; ++iter)
     {
@@ -856,8 +839,7 @@ BaseColorMapPlotWidget::zAxisFilterLowPassThreshold(double threshold)
 }
 
 void
-BaseColorMapPlotWidget::zAxisFilterHighPassPercentage(
-  double threshold_percentage)
+BaseColorMapPlotWidget::zAxisFilterHighPassPercentage(double threshold_percentage)
 {
   // This filter allows all the value greater than a threshold to remain
   // unchanged. Instead, all the values below the threshold will be reset to
@@ -900,8 +882,7 @@ BaseColorMapPlotWidget::zAxisFilterHighPassPercentage(
   new_color_map_plot_config.lastMaxZValue = std::numeric_limits<double>::min();
 
   // Filtered
-  QCPColorMapData *new_map_data =
-    new QCPColorMapData(keySize, valueSize, keyRange, valueRange);
+  QCPColorMapData *new_map_data = new QCPColorMapData(keySize, valueSize, keyRange, valueRange);
 
   for(int iter = 0; iter < keySize; ++iter)
     {
@@ -980,8 +961,7 @@ BaseColorMapPlotWidget::zAxisDataResetToOriginal()
   color_map_p->data()->clear();
 
   if(mpa_origColorMapData == nullptr)
-    throw(PappsoException(
-      "Not possible that the mpa_origColorMapData pointer be null."));
+    throw(PappsoException("Not possible that the mpa_origColorMapData pointer be null."));
 
   // We do no want that the color_map_p takes ownership of the data, because
   // these must remain there always, so pass true, to say that we want to copy
@@ -1057,8 +1037,7 @@ BaseColorMapPlotWidget::zAxisScale() const
 
 
 void
-BaseColorMapPlotWidget::setPlottingColor(QCPAbstractPlottable *plottable_p,
-                                         const QColor &new_color)
+BaseColorMapPlotWidget::setPlottingColor(QCPAbstractPlottable *plottable_p, const QColor &new_color)
 {
   Q_UNUSED(plottable_p);
 
@@ -1242,12 +1221,10 @@ BaseColorMapPlotWidget::dataTo3ColString(QString &data_string)
   QString debug_string;
 
   // Iterate in the matrix' key axis (DT, for example)
-  for(int key_iter = key_index_lower_range; key_iter < key_index_upper_range;
-      ++key_iter)
+  for(int key_iter = key_index_lower_range; key_iter < key_index_upper_range; ++key_iter)
     {
       // Iterate in the matrix' value axis (MZ, for example)
-      for(int value_iter = value_index_lower_range;
-          value_iter < value_index_upper_range;
+      for(int value_iter = value_index_lower_range; value_iter < value_index_upper_range;
           ++value_iter)
         {
           // This would be the DT value (x axis)
@@ -1258,12 +1235,11 @@ BaseColorMapPlotWidget::dataTo3ColString(QString &data_string)
 
           map_data->cellToCoord(key_iter, value_iter, &key, &value);
 
-          data_string +=
-            QString("%1 %2 %3\n")
-              .arg(key, 0, 'f', 6, ' ')
-              .arg(value, 0, 'f', 6, ' ')
-              // The intensity without decimals
-              .arg(map_data->cell(key_iter, value_iter), 0, 'f', 0, ' ');
+          data_string += QString("%1 %2 %3\n")
+                           .arg(key, 0, 'f', 6, ' ')
+                           .arg(value, 0, 'f', 6, ' ')
+                           // The intensity without decimals
+                           .arg(map_data->cell(key_iter, value_iter), 0, 'f', 0, ' ');
         }
     }
 
@@ -1302,8 +1278,7 @@ BaseColorMapPlotWidget::dataToMatrixString(QString &data_string, bool detailed)
   // At this point, we can write the header of the key data (that is the dt
   // key values).
 
-  for(int key_iter = key_index_lower_range; key_iter < key_index_upper_range;
-      ++key_iter)
+  for(int key_iter = key_index_lower_range; key_iter < key_index_upper_range; ++key_iter)
     {
       double current_key_value;
       map_data->cellToCoord(key_iter, 0, &current_key_value, nullptr);
@@ -1336,22 +1311,17 @@ BaseColorMapPlotWidget::dataToMatrixString(QString &data_string, bool detailed)
   // Because we want the matrix to be presented the same, we need to fill in the
   // matrix from top to bottom starting from higher m/z values.
 
-  for(int value_iter = value_index_upper_range;
-      value_iter >= value_index_lower_range;
-      --value_iter)
+  for(int value_iter = value_index_upper_range; value_iter >= value_index_lower_range; --value_iter)
     {
 
-      for(int key_iter = key_index_lower_range;
-          key_iter < key_index_upper_range;
-          ++key_iter)
+      for(int key_iter = key_index_lower_range; key_iter < key_index_upper_range; ++key_iter)
         {
           double intensity = map_data->cell(key_iter, value_iter);
 
           // Only to report debug messages
           double key_double;
           double value_double;
-          map_data->cellToCoord(
-            key_iter, value_iter, &key_double, &value_double);
+          map_data->cellToCoord(key_iter, value_iter, &key_double, &value_double);
 
           // qDebug() << "Currently iterated cell: " << key_iter << ","
           //<< value_iter << "with values:" << key_double << ","
