@@ -36,12 +36,12 @@
 #include "pappsomspp/core/exception/exceptionnotpossible.h"
 #include "pappsomspp/core/pappsoexception.h"
 
-
 namespace pappso
 {
 
 
-BaseTracePlotWidget::BaseTracePlotWidget(QWidget *parent) : BasePlotWidget(parent)
+BaseTracePlotWidget::BaseTracePlotWidget(QWidget *parent)
+  : BasePlotWidget(parent)
 {
   // We can afford to call createAllAncillaryItems() in this derived class
   // because all the items will have been created *before* the addition of plots
@@ -63,7 +63,6 @@ BaseTracePlotWidget::BaseTracePlotWidget(QWidget *parent) : BasePlotWidget(paren
   createAllAncillaryItems();
 }
 
-
 BaseTracePlotWidget::BaseTracePlotWidget(QWidget *parent,
                                          const QString &x_axis_label,
                                          const QString &y_axis_label)
@@ -89,7 +88,6 @@ BaseTracePlotWidget::BaseTracePlotWidget(QWidget *parent,
   createAllAncillaryItems();
 }
 
-
 //! Destruct \c this BaseTracePlotWidget instance.
 /*!
 
@@ -101,7 +99,6 @@ BaseTracePlotWidget::~BaseTracePlotWidget()
 {
 }
 
-
 void
 BaseTracePlotWidget::setGraphData(int graph_index,
                                   const std::vector<double> &keys,
@@ -115,7 +112,6 @@ BaseTracePlotWidget::setGraphData(int graph_index,
   return setGraphData(graph_p, keys, values);
 }
 
-
 void
 BaseTracePlotWidget::setGraphData(QCPGraph *graph_p,
                                   const std::vector<double> &keys,
@@ -162,7 +158,6 @@ BaseTracePlotWidget::setGraphData(QCPGraph *graph_p,
   replot();
 }
 
-
 void
 BaseTracePlotWidget::clearGraphData(int graph_index)
 {
@@ -178,14 +173,14 @@ BaseTracePlotWidget::clearGraphData(int graph_index)
   replot();
 }
 
-
 QCPGraph *
 BaseTracePlotWidget::addTrace(const pappso::Trace &trace, const QColor &color)
 {
   // qDebug();
 
   if(!color.isValid())
-    throw PappsoException(QString("The color to be used for the plot graph is invalid."));
+    throw PappsoException(
+      QString("The color to be used for the plot graph is invalid."));
 
   // This seems to be unpleasant.
   // setFocus();
@@ -252,10 +247,12 @@ BaseTracePlotWidget::addTrace(const pappso::Trace &trace, const QColor &color)
   // Connect the signal of selection change so that we can re-emit it for the
   // widget that is using *this widget.
 
-  connect(
-    graph_p,
-    static_cast<void (QCPAbstractPlottable::*)(bool)>(&QCPAbstractPlottable::selectionChanged),
-    [this, graph_p]() { emit plottableSelectionChangedSignal(graph_p, graph_p->selected()); });
+  connect(graph_p,
+          static_cast<void (QCPAbstractPlottable::*)(bool)>(
+            &QCPAbstractPlottable::selectionChanged),
+          [this, graph_p]() {
+            emit plottableSelectionChangedSignal(graph_p, graph_p->selected());
+          });
 
   // Rescaling the axes is actually unpleasant if there are more than one
   // graph in the plot widget and that we are adding one. So only, rescale if
@@ -272,6 +269,85 @@ BaseTracePlotWidget::addTrace(const pappso::Trace &trace, const QColor &color)
   return graph_p;
 }
 
+QCPBars *
+BaseTracePlotWidget::addBars(const pappso::Trace &bars, const QColor &color)
+{
+  qDebug();
+
+  if(!color.isValid())
+    throw PappsoException(
+      QString("The color to be used for the plot graph is invalid."));
+
+  // This seems to be unpleasant.
+  // setFocus();
+
+  QCPBars *bars_p = new QCPBars(xAxis, yAxis);
+  bars_p->setWidthType(QCPBars::WidthType::wtPlotCoords);
+  bars_p->setWidth(0.0005);
+  bars_p->setLayer("plotsLayer");
+
+  // Now depracated as of 20200924
+  // graph_p->setData(QVector<double>::fromStdVector(trace.xValues()),
+  // QVector<double>::fromStdVector(trace.yValues()));
+
+  std::vector<double> x_values = bars.xValues();
+  QVector<double> key_qvector;
+  key_qvector.assign(x_values.begin(), x_values.end());
+
+  std::vector<double> y_values = bars.yValues();
+  QVector<double> value_qvector;
+  value_qvector.assign(y_values.begin(), y_values.end());
+
+  qDebug() << "The size of the x values for trace is:" << key_qvector.size()
+           << "and for y values is:" << value_qvector.size();
+
+#if 0
+
+  qDebug() << "The size of the x values for trace is:" << key_qvector.size()
+           << "and for y values is:" << value_qvector.size();
+
+  QString text;
+
+  for(qsizetype iter = 0; iter < key_qvector.size(); ++iter)
+    text += QString("(%1,%2)\n")
+              .arg(key_qvector.at(iter), 0, 'f', 6)
+              .arg(value_qvector.at(iter), 0, 'f', 6);
+
+  qDebug().noquote() << text;
+
+#endif
+
+
+  bars_p->setData(key_qvector, value_qvector, true);
+
+  QPen pen = graph()->pen();
+  pen.setColor(color);
+  graph()->setPen(pen);
+
+  // Connect the signal of selection change so that we can re-emit it for the
+  // widget that is using *this widget.
+
+  connect(bars_p,
+          static_cast<void (QCPAbstractPlottable::*)(bool)>(
+            &QCPAbstractPlottable::selectionChanged),
+          [this, bars_p]() {
+            emit plottableSelectionChangedSignal(bars_p, bars_p->selected());
+          });
+
+  // Rescaling the axes is actually unpleasant if there are more than one
+  // graph in the plot widget and that we are adding one. So only, rescale if
+  // the number of graphs is == 1, that is we are adding the first one.
+
+  if(graphCount() == 1)
+    {
+      rescaleAxes();
+      resetAxesRangeHistory();
+    }
+
+  replot();
+
+  return bars_p;
+}
 
 //! Find a minimal integration range starting at an existing data point
 /*!
@@ -282,7 +358,9 @@ BaseTracePlotWidget::addTrace(const pappso::Trace &trace, const QColor &color)
 
 */
 bool
-BaseTracePlotWidget::findIntegrationLowerRangeForKey(int index, double key, QCPRange &range)
+BaseTracePlotWidget::findIntegrationLowerRangeForKey(int index,
+                                                     double key,
+                                                     QCPRange &range)
 {
 
   // Given a key double value, we want to know what is the range that will
@@ -302,7 +380,8 @@ BaseTracePlotWidget::findIntegrationLowerRangeForKey(int index, double key, QCPR
   // QCPDataContainer< DataType > is a Class Template. So in this context,
   // DataType is QCPGraphData.
   // QCPGraphData is the data point, that is the (key,value) pair.
-  QSharedPointer<QCPGraphDataContainer> graph_data_container_p = theGraph->data();
+  QSharedPointer<QCPGraphDataContainer> graph_data_container_p =
+    theGraph->data();
 
   QCPDataRange dataRange = graph_data_container_p->dataRange();
 
@@ -348,8 +427,11 @@ BaseTracePlotWidget::findIntegrationLowerRangeForKey(int index, double key, QCPR
       // Finally the generic case where the user point to any point *in* the
       // graph.
 
-      range.lower = graph_data_container_p->findBegin(key, /*expandedRange*/ true)->key;
-      range.upper = std::prev(graph_data_container_p->findEnd(key, /*expandedRange*/ true))->key;
+      range.lower =
+        graph_data_container_p->findBegin(key, /*expandedRange*/ true)->key;
+      range.upper =
+        std::prev(graph_data_container_p->findEnd(key, /*expandedRange*/ true))
+          ->key;
 
       return true;
     }
@@ -357,7 +439,6 @@ BaseTracePlotWidget::findIntegrationLowerRangeForKey(int index, double key, QCPR
   return false;
 }
 
-
 std::vector<double>
 BaseTracePlotWidget::getValuesX(int graph_index) const
 {
@@ -368,7 +449,8 @@ BaseTracePlotWidget::getValuesX(int graph_index) const
   if(graph_p == nullptr)
     qFatal("Programming error.");
 
-  QSharedPointer<QCPGraphDataContainer> graph_data_container_p = graph_p->data();
+  QSharedPointer<QCPGraphDataContainer> graph_data_container_p =
+    graph_p->data();
 
   // Iterate in the keys
   auto beginIt = graph_data_container_p->begin();
@@ -380,7 +462,6 @@ BaseTracePlotWidget::getValuesX(int graph_index) const
   return keys;
 }
 
-
 std::vector<double>
 BaseTracePlotWidget::getValuesY(int graph_index) const
 {
@@ -391,7 +472,8 @@ BaseTracePlotWidget::getValuesY(int graph_index) const
   if(graph_p == nullptr)
     qFatal("Programming error.");
 
-  QSharedPointer<QCPGraphDataContainer> graph_data_container_p = graph_p->data();
+  QSharedPointer<QCPGraphDataContainer> graph_data_container_p =
+    graph_p->data();
 
   // Iterate in the values
   auto beginIt = graph_data_container_p->begin();
@@ -403,9 +485,9 @@ BaseTracePlotWidget::getValuesY(int graph_index) const
   return values;
 }
 
-
 QCPRange
-BaseTracePlotWidget::getValueRangeOnKeyRange(QCPAbstractPlottable *plottable_p, bool &ok)
+BaseTracePlotWidget::getValueRangeOnKeyRange(QCPAbstractPlottable *plottable_p,
+                                             bool &ok)
 {
 
   // The X axis range is set. But we want to find for that X axis range the
@@ -440,7 +522,8 @@ BaseTracePlotWidget::getValueRangeOnKeyRange(QCPAbstractPlottable *plottable_p,
         {
           QCPGraph *plottable_p = graph(iter);
 
-          QCPRange value_range = plottable_p->getValueRange(ok, QCP::SignDomain::sdBoth, key_range);
+          QCPRange value_range =
+            plottable_p->getValueRange(ok, QCP::SignDomain::sdBoth, key_range);
 
           if(ok)
             found_range = true;
@@ -458,7 +541,6 @@ BaseTracePlotWidget::getValueRangeOnKeyRange(QCPAbstractPlottable *plottable_p,
     }
 }
 
-
 QCPRange
 BaseTracePlotWidget::getValueRangeOnKeyRange(int index, bool &ok)
 {
@@ -476,7 +558,6 @@ BaseTracePlotWidget::getValueRangeOnKeyRange(int index, bool &ok)
   return getValueRangeOnKeyRange(plottable_p, ok);
 }
 
-
 double
 BaseTracePlotWidget::getYatX(double x, QCPGraph *graph_p)
 {
@@ -499,7 +580,6 @@ BaseTracePlotWidget::getYatX(double x, QCPGraph *graph_p)
   return value;
 }
 
-
 double
 BaseTracePlotWidget::getYatX(double x, int index)
 {
@@ -511,11 +591,11 @@ BaseTracePlotWidget::getYatX(double x, int index)
   return getYatX(x, graph_p);
 }
 
-
 void
-BaseTracePlotWidget::axisDoubleClickHandler(QCPAxis *axis,
-                                            [[maybe_unused]] QCPAxis::SelectablePart part,
-                                            QMouseEvent *event)
+BaseTracePlotWidget::axisDoubleClickHandler(
+  QCPAxis *axis,
+  [[maybe_unused]] QCPAxis::SelectablePart part,
+  QMouseEvent *event)
 {
   // qDebug();
 
@@ -580,7 +660,6 @@ BaseTracePlotWidget::axisDoubleClickHandler(QCPAxis *axis,
   replot();
 }
 
-
 void
 BaseTracePlotWidget::axisRescale()
 {
@@ -602,7 +681,8 @@ BaseTracePlotWidget::axisRescale()
       // We are changing the range of the X axis.
 
       // What is the x delta ?
-      double xDelta = m_context.m_currentDragPoint.x() - m_context.m_startDragPoint.x();
+      double xDelta =
+        m_context.m_currentDragPoint.x() - m_context.m_startDragPoint.x();
 
       // If xDelta is < 0, the  we were dragging from right to left, we are
       // compressing the view on the x axis, by adding new data to the right
@@ -662,7 +742,8 @@ BaseTracePlotWidget::axisRescale()
       // We are changing the range of the Y axis.
 
       // What is the y delta ?
-      double yDelta = m_context.m_currentDragPoint.y() - m_context.m_startDragPoint.y();
+      double yDelta =
+        m_context.m_currentDragPoint.y() - m_context.m_startDragPoint.y();
 
       // See above for an explanation of the computation.
 
@@ -698,7 +779,6 @@ BaseTracePlotWidget::axisRescale()
   replot();
 }
 
-
 void
 BaseTracePlotWidget::axisReframe()
 {
@@ -710,14 +790,16 @@ BaseTracePlotWidget::axisReframe()
   // xAxis->setRange(sorted_start_drag_point_x,
   // sorted_start_drag_point_x + fabs(m_context.m_xDelta));
 
-  xAxis->setRange(QCPRange(m_context.m_xRegionRangeStart, m_context.m_xRegionRangeEnd));
+  xAxis->setRange(
+    QCPRange(m_context.m_xRegionRangeStart, m_context.m_xRegionRangeEnd));
 
   // Note that the y axis should be rescaled from current lower value to new
   // upper value matching the y-axis position of the cursor when the mouse
   // button was released.
 
   yAxis->setRange(xAxis->range().lower,
-                  std::max<double>(m_context.m_yRegionRangeStart, m_context.m_yRegionRangeEnd));
+                  std::max<double>(m_context.m_yRegionRangeStart,
+                                   m_context.m_yRegionRangeEnd));
 
   // qDebug() << "xaxis:" << xAxis->range().lower << "-" <<
   // xAxis->range().upper
@@ -744,7 +826,6 @@ BaseTracePlotWidget::axisReframe()
   replot();
 }
 
-
 void
 BaseTracePlotWidget::axisZoom()
 {
@@ -754,7 +835,8 @@ BaseTracePlotWidget::axisZoom()
   // value. Simply craft a QCPRange that will swap the values if lower is not
   // < than upper QCustomPlot calls this normalization).
 
-  xAxis->setRange(QCPRange(m_context.m_xRegionRangeStart, m_context.m_xRegionRangeEnd));
+  xAxis->setRange(
+    QCPRange(m_context.m_xRegionRangeStart, m_context.m_xRegionRangeEnd));
 
   // If the shift modifier key is pressed, then the user want the y axis
   // to be full scale.
@@ -768,7 +850,8 @@ BaseTracePlotWidget::axisZoom()
       yAxis->setRange(value_range);
     }
   else
-    yAxis->setRange(QCPRange(m_context.m_yRegionRangeStart, m_context.m_yRegionRangeEnd));
+    yAxis->setRange(
+      QCPRange(m_context.m_yRegionRangeStart, m_context.m_yRegionRangeEnd));
 
   updateContextXandYAxisRanges();
 
@@ -832,27 +915,40 @@ BaseTracePlotWidget::axisPan()
   replot();
 }
 
-
 pappso::Trace
-BaseTracePlotWidget::toTrace(int index) const
+BaseTracePlotWidget::toTrace(int index, bool only_visible_range) const
 {
   QCPGraph *graph_p = graph(index);
 
-  return toTrace(graph_p);
+  return toTrace(graph_p, only_visible_range);
 }
 
-
 pappso::Trace
-BaseTracePlotWidget::toTrace(const QCPGraph *graph_p) const
+BaseTracePlotWidget::toTrace(const QCPGraph *graph_p, bool only_visible_range) const
 {
   if(graph_p == nullptr)
     qFatal("Programming error. Pointer cannot be nullptr.");
 
   pappso::Trace trace;
 
+  if(only_visible_range)
+    {
+      // qDebug() << "Only visible range.";
+
+      QCPRange x_axis_range = xAxis->range();
+
+      // qDebug() << "Returning for visible range:" << x_axis_range;
+
+      return toTrace(x_axis_range, graph_p);
+    }
+  else
+    {
+      qDebug() << "Failed to get key range. Will return full key range.";
+    }
+
   QSharedPointer<QCPGraphDataContainer> graph_data_container_p = graph_p->data();
 
-  // Iterate in the keys
+  // Iterate in the *all* the trace keys
   auto beginIt = graph_data_container_p->begin();
   auto endIt   = graph_data_container_p->end();
 
@@ -862,7 +958,6 @@ BaseTracePlotWidget::toTrace(const QCPGraph *graph_p) const
   return trace;
 }
 
-
 pappso::Trace
 BaseTracePlotWidget::toTrace(const QCPRange &x_axis_range, int index) const
 {
@@ -874,10 +969,11 @@ BaseTracePlotWidget::toTrace(const QCPRange &x_axis_range, int index) const
   return toTrace(x_axis_range, graph_p);
 }
 
-
 pappso::Trace
-BaseTracePlotWidget::toTrace(const QCPRange &x_axis_range, const QCPGraph *graph_p) const
+BaseTracePlotWidget::toTrace(const QCPRange &x_axis_range,
+                             const QCPGraph *graph_p) const
 {
+  // qDebug() << "to Trace only key visible range:" << x_axis_range;
 
   // Make a Trace with the data in the range.
   Trace data_trace;
@@ -887,11 +983,16 @@ BaseTracePlotWidget::toTrace(const QCPRange &x_axis_range, const QCPGraph *graph
   graph_data_container_sp = graph_p->data();
 
   // Grab the iterator to the start to the x axis range
+  // If expandedRange is true, the data point just
+  // below sortKey will be considered, otherwise the one just above.
   auto beginIt = graph_data_container_sp->findBegin(x_axis_range.lower,
-                                                    /*expandedRange*/ true);
+                                                    /*expandedRange*/ false);
   // Grab the iterator to the end of the axis range
+  // If expandedRange is true, the data point just
+  // above sortKey will be considered, otherwise the
+  // one just below.
   auto endIt = graph_data_container_sp->findEnd(x_axis_range.upper,
-                                                /*expandedRange*/ true);
+                                                /*expandedRange*/ false);
 
   for(auto iter = beginIt; iter != endIt; ++iter)
     data_trace.push_back(DataPoint(iter->key, iter->value));
@@ -900,4 +1001,34 @@ BaseTracePlotWidget::toTrace(const QCPRange &x_axis_range, const QCPGraph *graph
 }
 
 
+pappso::Trace
+BaseTracePlotWidget::toTrace(const QCPRange &x_axis_range, const QCPBars *bars_p) const
+{
+  // qDebug() << "to Trace only key visible range:" << x_axis_range;
+
+  // Make a Trace with the data in the range.
+  Trace data_trace;
+
+  QSharedPointer<QCPBarsDataContainer> bars_data_container_sp;
+
+  bars_data_container_sp = bars_p->data();
+
+  // Grab the iterator to the start to the x axis range
+  // If expandedRange is true, the data point just
+  // below sortKey will be considered, otherwise the one just above.
+  auto beginIt = bars_data_container_sp->findBegin(x_axis_range.lower,
+                                                   /*expandedRange*/ false);
+  // Grab the iterator to the end of the axis range
+  // If expandedRange is true, the data point just
+  // above sortKey will be considered, otherwise the
+  // one just below.
+  auto endIt = bars_data_container_sp->findEnd(x_axis_range.upper,
+                                               /*expandedRange*/ false);
+
+  for(auto iter = beginIt; iter != endIt; ++iter)
+    data_trace.push_back(DataPoint(iter->key, iter->value));
+
+  return data_trace;
+}
+
 } // namespace pappso
