@@ -55,7 +55,7 @@ TEST_CASE("Extracting XIC from timsdata", "[TimsXicExtractor]")
 {
   qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
 
-#if USEPAPPSOTREE == 1
+#if USE_PAPPSO_TREE == 1
 
   QString file_path_name;
   /*
