@@ -7,6 +7,7 @@
 #include <iomanip>
 #include <odsstream/odsdocwriter.h>
 #include <QJsonDocument>
+#include <QJsonArray>
 #include <pappsomspp/core/psm/peptidespectrummatch.h>
 #include <pappsomspp/core/psm/peptideisotopespectrummatch.h>
 #include <pappsomspp/core/amino_acid/aastringcodec.h>
@@ -66,3 +67,6 @@ void writeJsonPsmIsotope(const QString &filein,
 void writeJsonCodeList(const QString &filein,
                        const std::vector<uint32_t> code_list,
                        const pappso::AaStringCodec &aa_codec);
+
+
+QJsonArray toJson(const std::vector<double> &myVec);
