@@ -63,6 +63,27 @@ TEST_CASE("cbor psm map test suite.", "[cborsage]")
 {
   // Set the debugging message formatting pattern.
   qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
+  
+  
+  SECTION("..:: PSM cbor features::..", "[cborfeatures]")
+  {
+    pappso::UiMonitorVoid monitor;
+
+    QFile cbor_file(
+      "/gorgone/pappso/data_extraction_pappso/sage_output/sage_output.cbor");
+    cbor_file.open(QIODevice::ReadOnly);
+
+
+    QFile fileods("test.ods");
+    OdsDocWriter writer(&fileods);
+
+
+    CborTest cbor_pappso(writer);
+    cbor_pappso.readCbor(&cbor_file, monitor);
+    // xic_writer.write(xic);
+    writer.close();
+    fileods.close();
+  }
 
   SECTION("..:: PSM cbor features::..", "[cborfeatures]")
   {
