@@ -59,6 +59,9 @@ TEST_CASE("Test MsRunReaderTims new API", "[MsRunReaderTims]")
   qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
 
 
+  int argc(0);
+  char *argv[]          = {};
+  QCoreApplication *app = new QCoreApplication(argc, argv);
   SECTION("..::  test retrieving precursor with simple tims reader ::..")
 
   {
