@@ -58,13 +58,12 @@ TEST_CASE("cbor psm map test suite.", "[mzcbor]")
     REQUIRE(qualifiedMassSpectrum.getRtInSeconds() == 0.76824700000000201);
     REQUIRE(qualifiedMassSpectrum.getMsLevel() == 1);
     REQUIRE(qualifiedMassSpectrum.getMassSpectrumCstSPtr().get()->size() == 1140);
-    
-    qualifiedMassSpectrum =
-      msrunA01.get()->qualifiedMassSpectrum(77766, true);
-    REQUIRE(qualifiedMassSpectrum.getRtInSeconds() == 0.76824700000000201);
-    REQUIRE(qualifiedMassSpectrum.getMsLevel() == 1);
-    REQUIRE(qualifiedMassSpectrum.getMassSpectrumCstSPtr().get()->size() == 1140);
-    
+
+    qualifiedMassSpectrum = msrunA01.get()->qualifiedMassSpectrum(77766, true);
+    REQUIRE(qualifiedMassSpectrum.getRtInSeconds() == 933.30781799999999748);
+    REQUIRE(qualifiedMassSpectrum.getMsLevel() == 2);
+    REQUIRE(qualifiedMassSpectrum.getMassSpectrumCstSPtr().get()->size() == 1102);
+
     qDebug();
     // msrunA01.get()->getRetentionTimeLine();
   }
