@@ -39,12 +39,12 @@ using namespace Catch::Matchers;
 #endif
 
 
-#include <pappsomspp/mzrange.h>
-#include <pappsomspp/peptide/peptidenaturalisotopelist.h>
-#include <pappsomspp/peptide/peptidefragmentionlistbase.h>
-#include <pappsomspp/massspectrum/massspectrum.h>
-#include <pappsomspp/psm/xtandem/xtandemhyperscore.h>
-#include <pappsomspp/pappsoexception.h>
+#include <pappsomspp/core/mzrange.h>
+#include <pappsomspp/core/peptide/peptidenaturalisotopelist.h>
+#include <pappsomspp/core/peptide/peptidefragmentionlistbase.h>
+#include <pappsomspp/core/massspectrum/massspectrum.h>
+#include <pappsomspp/core/psm/xtandem/xtandemhyperscore.h>
+#include <pappsomspp/core/pappsoexception.h>
 #include <iostream>
 #include <iomanip>
 #include <cmath>
