@@ -146,32 +146,6 @@ TEST_CASE("Fasta reader test suite.", "[Fasta]")
     INFO(" getSequenceByIndex(seq, 2)");
     fasta_file_indexer.getSequenceByIndex(seq, 2);
   }
-#if USEPAPPSOTREE == 1
-
-
-  SECTION("..:: Test Fasta big file indexer ::..", "[FastaBigIndexer]")
-  {
-    FastaSeq seq;
-    std::cout << std::endl
-              << "..:: Test Fasta big file indexer ::.." << std::endl;
-    QFileInfo file2("/gorgone/pappso/moulon/database/Genome_Z_mays_5a.fasta");
-    pappso::FastaFileIndexer big_fasta_file_indexer(file2);
-    big_fasta_file_indexer.getSequenceByIndex(seq, 12);
-
-    std::cout << std::endl << seq.getDescription().toStdString() << std::endl;
-
-    // GRMZM2G147579_P01
-    // GRMZM2G147579_P01 NP_001159186 hypothetical protein LOC100304271
-    // seq=translation; coord=5:217415249..217417029:-1;
-    // parent_transcript=GRMZM2G147579_T01; parent_gene=GRMZM2G147579
-
-    REQUIRE(seq.getDescription() ==
-            "GRMZM2G147579_P01 NP_001159186 hypothetical protein LOC100304271 "
-            "seq=translation; coord=5:217415249..217417029:-1; "
-            "parent_transcript=GRMZM2G147579_T01; parent_gene=GRMZM2G147579");
-  }
-
-#endif
 
   SECTION("..:: Test fuzzy fasta file indexer ::..", "[FastaFuzzyIndexer]")
   {
