@@ -31,6 +31,7 @@
 
 // #define CATCH_CONFIG_MAIN
 
+#include <catch2/catch_message.hpp>
 #include <catch2/catch_test_macros.hpp>
 #include <catch2/catch_approx.hpp>
 #include <catch2/matchers/catch_matchers_vector.hpp>
@@ -50,6 +51,12 @@
 #include <QDebug>
 #include <QtCore>
 #include <QFile>
+#include <qbuffer.h>
+#include <qjsondocument.h>
+#include <qjsonobject.h>
+#include <qlogging.h>
+#include "pappsomspp/core/processing/cbor/cborstreamreader.h"
+#include "pappsomspp/core/processing/cbor/cborstreamwriter.h"
 #include "tests/tests-config.h"
 #include "common.h"
 
@@ -70,13 +77,13 @@ class CustomHandler : public OdsDocHandlerInterface
    * order to retrieve information about the current data sheet.
    *
    */
-  virtual void startSheet(const QString &sheet_name [[maybe_unused]]) override{};
+  virtual void startSheet(const QString &sheet_name [[maybe_unused]]) override {};
 
   /**
    * callback that indicates the end of the current data sheet. Override it if
    * needed
    */
-  virtual void endSheet() override{
+  virtual void endSheet() override {
     // qDebug() << "endSheet";
   };
 
@@ -130,7 +137,7 @@ class CustomHandler : public OdsDocHandlerInterface
    * callback that report the end of the ODS document. Override it if you need
    * to know that reading is finished.
    */
-  virtual void endDocument() override{};
+  virtual void endDocument() override {};
 
   private:
   bool _is_title = true;
@@ -245,6 +252,24 @@ TEST_CASE("XIC test suite.", "[XIC]")
     REQUIRE_NOTHROW(
       readOdsXic(QString(CMAKE_SOURCE_DIR).append("/tests/data/xic/xic.ods"), xic_test));
 
+
+    WARN("test xic CBOR");
+
+    QBuffer buffer;
+    buffer.open(QIODevice::ReadWrite);
+    pappso::cbor::CborStreamWriter writer(&buffer);
+
+    writer.writeTrace(xic_test, "rt", "int");
+    buffer.seek(0);
+    pappso::cbor::CborStreamReader reader(&buffer);
+    QCborMap cbor_map_xic;
+    reader.readCborMap(cbor_map_xic);
+    QJsonObject json_xic = cbor_map_xic.toJsonObject();
+    QJsonDocument doc;
+    doc.setObject(json_xic);
+    qWarning() << doc.toJson();
+
+
     REQUIRE(xic_test.size() == 37);
     std::cout << std::endl << "..:: Test smooth filter ::.." << std::endl;
     FilterMorphoMean smooth(3);
